%/*************************************************************************
%**  
%**  figure5_sticky_wage.m: Plotting the structural SDFs of 
%**     output and consumption growth for sticky wage model
%**             
%**  
%**************************************************************************/

%/* filename: figure5_sticky_wage.m
%** created:  01/14/08
%** modified: 07/12/12
%*/

clear
clc


%/* Set the path */
pathspec;

%/* Choose VAR lag length */
varlag = 2;

%/**************** Loading structural SDFs of DlnY to permanent shock: spec 2 ******************/

  % sample
  loadsdm = [mainpath '/spec0/info1/VAR' num2str(varlag) '/sample_impl_spect_20_p.mat'];
  load(loadsdm,'-ascii')
  sirf_y_p_s = sample_impl_spect_20_p;
  
  % Empirical, Non-Habit, Habit
  loadsdm = [mainpath '/spec2/info1/VAR' num2str(varlag) '/mean_sirf_y_p.mat'];
  load(loadsdm,'-ascii')
  sirf_y_p_spec2 = mean_sirf_y_p;
  

%/**************** Loading structural SDFs of DlnY to permanent shock: spec 5 ******************/

  
  % Empirical, Non-Habit, Habit
  loadsdm = [mainpath '/spec5/info1/VAR' num2str(varlag) '/mean_sirf_y_p.mat'];
  load(loadsdm,'-ascii')
  sirf_y_p_spec5 = mean_sirf_y_p;
  
  
  

  


%/**************** Loading structural SDFs of DlnY to transitory shock: spec 2 ******************/

  % sample
  loadsdm = [mainpath '/spec0/info1/VAR' num2str(varlag) '/sample_impl_spect_20_t.mat'];
  load(loadsdm,'-ascii')
  sirf_y_t_s = sample_impl_spect_20_t;
  
  % Empirical, Non-Habit, Habitbashline
  loadsdm = [mainpath '/spec2/info1/VAR' num2str(varlag) '/mean_sirf_y_t.mat'];
  load(loadsdm,'-ascii')
  sirf_y_t_spec2 = mean_sirf_y_t;
  
  
%/**************** Loading structural SDFs of DlnY to transitory shock: spec 5 ******************/

  
  % Empirical, Non-Habit, Habit
  loadsdm = [mainpath '/spec5/info1/VAR' num2str(varlag) '/mean_sirf_y_t.mat'];
  load(loadsdm,'-ascii')
  sirf_y_t_spec5 = mean_sirf_y_t;
  
  


 
 


%/**************** Loading structural SDFs of DlnC to permanent shock: spec 2 ******************/

  % sample
  loadsdm = [mainpath '/spec0/info2/VAR' num2str(varlag) '/sample_impl_spect_20_p.mat'];
  load(loadsdm,'-ascii')
  sirf_c_p_s = sample_impl_spect_20_p;
  
  % Empirical, Non-Habit, Habit
  loadsdm = [mainpath '/spec2/info2/VAR' num2str(varlag) '/mean_sirf_c_p.mat'];
  load(loadsdm,'-ascii')
  sirf_c_p_spec2 = mean_sirf_c_p;
  
  
  
%/**************** Loading structural SDFs of DlnC to permanent shock: spec 5 ******************/

  
  % Empirical, Non-Habit, Habit
  loadsdm = [mainpath '/spec5/info2/VAR' num2str(varlag) '/mean_sirf_c_p.mat'];
  load(loadsdm,'-ascii')
  sirf_c_p_spec5 = mean_sirf_c_p;
  
  
 

%/**************** Loading structural SDFs of DlnC to transitory shock: spec 2 ******************/

  % sample
  loadsdm = [mainpath '/spec0/info2/VAR' num2str(varlag) '/sample_impl_spect_20_t.mat'];
  load(loadsdm,'-ascii')
  sirf_c_t_s = sample_impl_spect_20_t;
  
  % Empirical, Non-Habit, Habit
  loadsdm = [mainpath '/spec2/info2/VAR' num2str(varlag) '/mean_sirf_c_t.mat'];
  load(loadsdm,'-ascii')
  sirf_c_t_spec2 = mean_sirf_c_t;
  
  
%/**************** Loading structural SDFs of DlnC to transitory shock: spec 5 ******************/

  
  % Empirical, Non-Habit, Habit
  loadsdm = [mainpath '/spec5/info2/VAR' num2str(varlag) '/mean_sirf_c_t.mat'];
  load(loadsdm,'-ascii')
  sirf_c_t_spec5 = mean_sirf_c_t;
  
  
  

  
  

%/**************** Plot figure ******************/
   
  
  
  figure1 = figure(...
  'PaperType','usletter',...
  'PaperUnits','inches',...
  'PaperOrientation','landscape',...
  'PaperPosition',[-0.85 -0.5 12.5 9],...
  'PaperSize',[11 8.5]); 

%/********* DlnY to permanent shock ********************%

% spec 2%
% Create subplot
 subplot(4,2,1,'Parent',figure1,'XTickLabel',{'','8','4','2','1'},...
    'XTick',[0 20 40 80 157]);
% Uncomment the following line to preserve the X-limits of the axes
 xlim([0 314]);
box('on');
hold('all');

% Create multiple lines using matrix input to plot
 plot1 = plot(sirf_y_p_spec2,'LineWidth',2);

 
set(plot1(1),'DisplayName','Empirical');
set(plot1(2),'DisplayName','Non-Habit','LineStyle','--');
set(plot1(3),'DisplayName','Habit','LineStyle','-.');
 

% Create xlabel
%xlabel({'years per cycle'});

% Create title
title('Only Sticky Wages with AR money growth','fontsize',6);



% spec 5%
% Create subplot
 subplot(4,2,2,'Parent',figure1,'XTickLabel',{'','8','4','2','1'},...
    'XTick',[0 20 40 80 157]);
% Uncomment the following line to preserve the X-limits of the axes
 xlim([0 314]);
box('on');
hold('all');

% Create multiple lines using matrix input to plot
 plot2 = plot(sirf_y_p_spec5,'LineWidth',2);

 
set(plot2(1),'DisplayName','Empirical');
set(plot2(2),'DisplayName','Non-Habit','LineStyle','--');
set(plot2(3),'DisplayName','Habit','LineStyle','-.');
 

% Create xlabel
%xlabel({'years per cycle'});

% Create title
title('Only Sticky Wages with Taylor rule','fontsize',6);


 
%/********* DlnY to transitory shock ********************%

% spec 2%
% Create subplot
 subplot(4,2,3,'Parent',figure1,'XTickLabel',{'','8','4','2','1'},...
    'XTick',[0 20 40 80 157]);
% Uncomment the following line to preserve the X-limits of the axes
 xlim([0 314]);
box('on');
hold('all');

% Create multiple lines using matrix input to plot
plot3 = plot(sirf_y_t_spec2,'LineWidth',2);


set(plot3(1),'DisplayName','Empirical');
set(plot3(2),'DisplayName','Non-Habit','LineStyle','--');
set(plot3(3),'DisplayName','Habit','LineStyle','-.');


% spec 5%
% Create subplot
 subplot(4,2,4,'Parent',figure1,'XTickLabel',{'','8','4','2','1'},...
    'XTick',[0 20 40 80 157]);
% Uncomment the following line to preserve the X-limits of the axes
 xlim([0 314]);
box('on');
hold('all');

% Create multiple lines using matrix input to plot
plot4 = plot(sirf_y_t_spec5,'LineWidth',2);


set(plot4(1),'DisplayName','Empirical');
set(plot4(2),'DisplayName','Non-Habit','LineStyle','--');
set(plot4(3),'DisplayName','Habit','LineStyle','-.');





%/********* DlnC to permanent shock ********************%

% spec 2%
% Create subplot
 subplot(4,2,5,'Parent',figure1,'XTickLabel',{'','8','4','2','1'},...
    'XTick',[0 20 40 80 157]);
% Uncomment the following line to preserve the X-limits of the axes
 xlim([0 314]);
box('on');
hold('all');

% Create multiple lines using matrix input to plot
plot5 = plot(sirf_c_p_spec2,'LineWidth',2);


set(plot5(1),'DisplayName','Empirical');
set(plot5(2),'DisplayName','Non-Habit','LineStyle','--');
set(plot5(3),'DisplayName','Habit','LineStyle','-.');

% spec 5%
% Create subplot
 subplot(4,2,6,'Parent',figure1,'XTickLabel',{'','8','4','2','1'},...
    'XTick',[0 20 40 80 157]);
% Uncomment the following line to preserve the X-limits of the axes
 xlim([0 314]);
box('on');
hold('all');

% Create multiple lines using matrix input to plot
plot6 = plot(sirf_c_p_spec5,'LineWidth',2);


set(plot6(1),'DisplayName','Empirical');
set(plot6(2),'DisplayName','Non-Habit','LineStyle','--');
set(plot6(3),'DisplayName','Habit','LineStyle','-.');




%/********* DlnC to transitory shock ********************%

% spec 2%
% Create subplot
 subplot(4,2,7,'Parent',figure1,'XTickLabel',{'','8','4','2','1'},...
    'XTick',[0 20 40 80 157]);
% Uncomment the following line to preserve the X-limits of the axes
 xlim([0 314]);
box('on');
hold('all');

% Create multiple lines using matrix input to plot
plot7 = plot(sirf_c_t_spec2,'LineWidth',2);


set(plot7(1),'DisplayName','Empirical');
set(plot7(2),'DisplayName','Non-Habit','LineStyle','--');
set(plot7(3),'DisplayName','Habit','LineStyle','-.');

% Create xlabel
xlabel('years per cycle','fontsize',6);

% Create title
%title('Median spectral density');


% spec 5%
% Create subplot
 subplot(4,2,8,'Parent',figure1,'XTickLabel',{'','8','4','2','1'},...
    'XTick',[0 20 40 80 157]);
% Uncomment the following line to preserve the X-limits of the axes
 xlim([0 314]);
box('on');
hold('all');

% Create multiple lines using matrix input to plot
plot8 = plot(sirf_c_t_spec5,'LineWidth',2);


set(plot8(1),'DisplayName','Empirical');
set(plot8(2),'DisplayName','Non-Habit','LineStyle','--');
set(plot8(3),'DisplayName','Habit','LineStyle','-.');

% Create xlabel
xlabel('years per cycle','fontsize',6);


 