function [specv] = bartwin(xx,mxxm,obs) ;

%  **********************************************************
%  * BARTWIN.M computes the optimal weighting matrix using  *
%  * the Newey & West correction (Econometrica, 1987).      *
%  * They use a Bartlett kernal spectral density estimator. *
%  * m is the Optimal Bandwidth of the Bartlett kernal.  It *
%  * is chosen with an automatic bandwidth criterion.       *
%  **********************************************************

%  Optimal Lag Length of the Newey-West Correction

   m = round( 4*( (obs/100)^(2/9) ) ) ;

%  Compute Newey-West Correction

   specv = mxxm ;
   for j=1:m ;
      wij = 1.0 - (j/(m + 1.0)) ;  % The N-W optimal weights
      htj = xx(1:obs-j,:) ;
      hjt = xx(j+1:obs,:) ;
      omgj = htj'*hjt ;
      specv = specv + wij*(omgj + omgj') ;
   end ;

