function [c00, smimp1, smimp2, smimpl1, smimpl2] ...
                           = bqdecomp(bb,vcvee,sig,plags,tobs) ;

% ************************************************************
% * This MatLab proc computes a Blanchard-Quah Decomposition *
% * given unrestriced bivariate AR(p) slope coefficients.    *
% * The proc returns the structural VMA respresentation (the *
% * impulse response functions).  Assume LR(1,2) = 0.        *
% * 05/28/02                                                 *
% ************************************************************

% ----- Compute Unrestricted Impulse Response Functions ----- %
         
         %compm = [bb(1:2*plags,1)'; eye(plags-1) zeros(plags-1,plags+1); ...
         %         bb(1:2*plags,2)'; zeros(plags-1,plags) eye(plags-1) zeros(plags-1,1)] ;
        
         
         compm = [bb'; eye(2*(plags-1)) zeros(2*(plags-1),2)];
         

            u1 = [1 0] ;
            u2 = [0 1] ;
        rfimp1 = [u1; zeros(tobs-1,2)] ;
        rfimp2 = [u2; zeros(tobs-1,2)] ;
         capaj = eye(2*plags) ;
         for j = 2:tobs ;             % Recrusion generates unrestricted IRFs
                                      % Infinity = T.
             capaj = capaj*compm ;
             % impma = capaj([1 plags+1], [1 plags+1]);  % Pick off appropriate MA(j)
               impma = capaj([1 2], [1 2])  ;
             rfimp1(j,:) = rfimp1(j,:) + impma(1,:) ;
              rfimp2(j,:) = rfimp2(j,:) + impma(2,:) ;
         end ;

           b1  = sum(rfimp1) ; % Accumulate IRF over forecast horizon
           b11 = b1(1) ;      % long-run IRF at infinite forecast horizon
        %                      % 1st variable w/r/t 1st shock
           b12 = b1(2) ;      % 1st variable w/r/t 2nd shock
           b2  = sum(rfimp2) ;
           b21 = b2(1) ;      % 2nd variable w/r/t 1st shock
           b22 = b2(2) ;      % 2nd variable w/r/t 2nd shock
           bs  = [b11  b12; b21 b22] ;

           
        %   b = inv(eye(2*plags)-compm);
        %   bs = b(1:2,1:2);
           
           
% ----- Compute SVMA C0 Matrix ----- %

         c00i = eye(2) ; % initial guess of BQ structural impact matrix is identity matrix
           c0 = [c00i(1,1); c00i(1,2); c00i(2,1); c00i(2,2)] ;
            options = optimset('TolFun',1e-10,'Display','off');
            x = fsolve('Fbq2',c0,options,vcvee,bs) ; % fsolve(function,x0) is MatLab's nonlinear equation solver
            
          c00 = [x(1,1) x(2,1); x(3,1) x(4,1)] ; % estimates of BQ structural impact matrix
          c00 = real(sig*[x(1,1) x(2,1); x(3,1) x(4,1)]) ; 
                         % normalization by the covariance matrix of the structural shocks
          %c00               
         %c00*c00'-vcvee
         
% ----- Compute Structural Errors ----- %

       %smevar = evar*inv( c00 )' ;
       % smvcv = (smevar'*smevar)./tobs ;

      % stotrnd = cumsum(smevar(:,1)) ; % Accumulated innovations of I(1) trend shock

% ----- Compute Structural Impulse Response Functions ----- %

          su1 = u1*c00 ;
          su2 = u2*c00 ;
       smimp1 = [su1; zeros(tobs-1,2)] ;
       smimp2 = [su2; zeros(tobs-1,2)] ;
      smimpl1 = [su1; zeros(tobs-1,2)] ;
      smimpl2 = [su2; zeros(tobs-1,2)] ;
        capaj = eye(2*plags) ;
        impma = zeros(2,2) ;

        for j = 2:tobs ;
            capaj = capaj*compm ;
            %impma = capaj([1 plags+1], [1 plags+1])*c00 ;
            impma = capaj([1 2], [1 2])*c00  ;
            smimp1(j,:) = smimp1(j,:) + impma(1,:) ;
            smimp2(j,:) = smimp2(j,:) + impma(2,:) ;

            smimpl1(j,:) = smimpl1(j,:) + smimpl1(j-1,:) + impma(1,:) ;
            smimpl2(j,:) = smimpl2(j,:) + smimpl2(j-1,:) + impma(2,:) ;
        end ;
        
        
        
        

end

