function [Simdata,sig,valid,eig_FVRRSW_y, eig_FVRRSW_c] = kn_artdraw(priormat, mspec,mhabit)
%/*  kn_artdraw.m: Draw artificial data from NKMBC models
%**  
%
%/* Model's spec */
%   mspec = 1: NKMBC with AR money growth  
%         = 2; NKMBC with AR money growth and flexible price
%         = 3; NKMBC with AR money growth and flexible wage
%         = 4; NKMBC with Taylor rule
%         = 5; NKMBC with Taylor rule and flexible price
%         = 6: NKMBC with Taylor rule and flexible wage
%
%    
%*/

%
% Converted from Gauss procedure ARTDRAW 06/24/06
% modified: 09/24/06
%           12/24/08
%           10/05/09

 

  valid = 0;
  nsim  = 1000+196*5; %nsim = 2000; 
  nsim_start = 1001;
  
  
  % Draw the parameter vector from the prior distribution
           %paradraw = priordraw(priormat(:,1), priormat(:,2), priormat(:,3), priormat(:,4), priormat(:,5));
      paradraw = priormat;

      
      % if non-habit, h = 0
      if mhabit == 0;
        paradraw(1,1) = 0;
      end;
     
       %paradraw(3,1) = 0.9929; % Fix beta
   
     
   
       
  [npara,junk] = size(paradraw);
  alp  = paradraw(2,1);
  
  
  
  
  sig  = [ paradraw(npara-1,1)^2 0 ; 0  paradraw(npara,1)^2];
  cvarm  = chol(sig);
  
  
  % Solve DSGE models
   [STST, junk] = knsst(paradraw(:,1), mspec);
   [T1,T0,RC,retcode] = knsolv2(paradraw(:,1),mspec);
   gm = STST(11);
   
    
  if ( RC(1,1) == 1 ) && ( RC(2,1) == 1 );
  
  
    [nvar,junk] = size(T1);
 
  
    
    epsm = randn(nsim,2)*cvarm;
    
   % Simdata = zeros(196,4); We don't need this actually.
    ss = zeros(nsim,nvar);
    zt = zeros(nsim,1);
    et = zeros(nsim,1);
    
     for t = 2:nsim;
       et(t,:) = epsm(t,1);
       ss(t,:) = (T1*ss(t-1,:)' + T0*epsm(t,:)')';
       zt(t,:) = alp + zt(t-1,:) + et(t,1);
       t = t+1;
     end;

   

 
   %/*  NKMBC with Sticky Price, Sticky wage, and Variable Capital Utilization, and full indexation 
   %**      THE0*X(t) = THE1*X(t-1)+RRR*e(t)+PPI*eta(t)
   %**         1    2     3     4     5      6         7        8       9        10      11     12      
   %** X(t)=[ c(t), y(t),i(t), n(t), p(t),  pi(t)   lamda(t),  q(t),   W(t),    u(t),   mc(t),  R(t) 
   %**    13        14          15       16           17              18        19      20         21      22             
   %**   Ec(t+1), Ey(t+1),   Ei(t+1),  Epi(t+1)     Elambda(t+1),  Eq(t+1),  EW(t+1), Emc(t+1)  k(t+1), gm(t+1)
   %**       23      24      25
   %**      pi(t-1)  gm(t), epsilon(t)] 
   
   
 
   Simdata = log(1+ss(nsim_start:nsim,2))+log(STST(1))+zt(nsim_start:nsim,:);            % lnY(t)
   Simdata = [Simdata  log(1+ss(nsim_start:nsim,1))+log(STST(2))+zt(nsim_start:nsim,:)]; % lnC(t)
   Simdata = [Simdata  log(1+ss(nsim_start:nsim,3))+log(STST(3))+zt(nsim_start:nsim,:)]; % lnI(t)
   Simdata = [Simdata  log(1+ss(nsim_start:nsim,4))+log(STST(4))];                       % lnN(t)
   Simdata = [Simdata  log(1+ss(nsim_start:nsim,10))];                                    % u(t)
   Simdata = [Simdata  log(1+ss(nsim_start:nsim,11))];                                   % mc(t)
   Simdata = [Simdata  ss(nsim_start:nsim,6)];                                           % pi
   Simdata = [Simdata  ss(nsim_start:nsim,24)+gm];                                       % lnM(t)-lnM(t-1) 
   Simdata = [Simdata  zt(nsim_start:nsim,:)];                                           % lnA(t)
   
   
   
   % Check A, B, C, and D criterion by FVRRSW(AER,2007)
   e_y = zeros(1,25); e_y(1,2) = 1;
   e_c = zeros(1,25); e_c(1,1) = 1;
   e_eps = zeros(1,25); e_eps(1,25) = 1;
   e_dp = zeros(1,25); e_dp(1,6) = 1;
   e_dm = zeros(1,25); e_dm(1,24) = 1;
   
   Gamma_H = [(e_y+e_eps)*T1-e_y; (e_dp+e_dm-e_eps)*T1];
   Gamma_zeta = [(e_y+e_eps)*T0;  (e_dp+e_dm-e_eps)*T0];
   
   FVRRSW_y = T1-T0*inv(Gamma_zeta)*Gamma_H;
   eig_FVRRSW_y = eig(FVRRSW_y);
   
   
   Gamma_H = [(e_c+e_eps)*T1-e_c; (e_dp+e_dm-e_eps)*T1];
   Gamma_zeta = [(e_c+e_eps)*T0;  (e_dp+e_dm-e_eps)*T0];
   
   FVRRSW_c = T1-T0*inv(Gamma_zeta)*Gamma_H;
   eig_FVRRSW_c = eig(FVRRSW_c);
   
  end
  

 
  % Checking the existence and uniqueness of the equilibrium
  if (RC(1,1) == 1) && (RC(2,1) == 0);
    RC
    valid = 2;
    Simdata = 0;
    eig_FVRRSW_y=0;
    eig_FVRRSW_c=0;
    
  elseif ( RC(1,1) == -5 );
    RC
    valid = 1;
    Simdata = 0;
    eig_FVRRSW_y=0;
    eig_FVRRSW_c=0;
    
  end
   
  
  