function [priorsim] = kn_priordraw(pmean, pstdd, pshape, plow, pupper, ndraw);
%/* This procedure draws random samples from prior densities for
%** the structural parameters of the NKMBC models
%** pshape: 0 is point mass, both para and pstdd are ignored
%**         1 is BETA(mean,stdd)
%**         2 is GAMMA(mean,stdd)
%**         3 is NORMAL(mean,stdd)
%**         4 is INVGAMMA(s^2,nu)
%**
%** modifed: 09/24/06
%*/

a = 0;
b = 0;

% Seeds
state = [100020001; 200030002; 300040003; 400050004; 500060005; 600070006; 700080007; 800090008; 900100009; ...
        1000110010; 1100120011; 1200130012; 1300140013; 90001009; 80010008; 1600170016; 1700180017; ...
        1800190018; 1900200019; 2000210020; 2100220021; 2200230022; 2300240023; 2400250024;2500260025] ;
    
    
[npara,junk] = size(pshape);

priorsim = [zeros(ndraw,1)];


for i = 1:npara; % Iteration over the number of parameters

    % Set seed

    if pshape(i,1) == 1; %/* BETA Prior */
      a = (1-pmean(i))*pmean(i)^2/pstdd(i)^2 - pmean(i);
      b = a*(1/pmean(i) - 1);
         %y1 = gamrnd(a,1);
         %y2 = gamrnd(b,1);
         %prior = y1/(y1+y2);
      randn('state',state(i));
      rand('state',state(i));
      prior =  betarnd(a,b,ndraw+1000,1);  % ndraw*1 vector

   elseif pshape(i,1) == 2; %/* GAMMA PRIOR */
      b = pmean(i)/pstdd(i)^2;
      a = pmean(i)*b;
      randn('state',state(i));
      rand('state',state(i));
      prior = gamrnd(a,b,ndraw+1000,1);    % ndraw*1 vector

   elseif pshape(i,1) == 3; %/* GAUSSIAN PRIOR */
      a = pmean(i);
      b = pstdd(i);
      randn('state',state(i));
      prior = a+b*normrnd(0,1,ndraw+1000,1); % ndraw*1 vector

   elseif pshape(i,1) == 4; %/* INVGAMMA PRIOR */
       a =  2 + (pmean(i)/pstdd(i))^2 ;  
       b = 1/( pmean(i)*( 1 + (pmean(i)/pstdd(i))^2) ) ; 
      randn('state',state(i));
      rand('state',state(i));
      prior = 1./gamrnd(a,b,ndraw+1000,1);  % ndraw*1 vector

    elseif pshape(i,1) == 5; %/* Uniform prior */   
      a = pmean(i);
      b = pstdd(i);
      randn('state',state(i));
      rand('state',state(i));
      prior = unifrnd(a,b,ndraw+1000,1);
      
   elseif pshape(i,1) == 0;
      prior = ones(ndraw+1000,1).*pmean(i);

   end;

   
   priormat = 0;
   
   for j = 1:ndraw+1000;
       
      if (prior(j) > plow(i)) & (prior(j) < pupper(i));  % If one of the elements is outside the interval, repeat.
   
          priormat = [priormat; prior(j)];
          j = j + 1;
      else
          priormat = priormat;
          j = j ;
      end
          
   end
     
     priormat = priormat(2:ndraw+1,1);
 
     priorsim = [priorsim priormat];
     i = i + 1;
end;


priorsim = priorsim(:,2:npara+1);


