function [T1,T0,RC,retcode] = knsolv2(para,spec);
%/*  knsolve2.m: this procedure computes the solution of the log linearized NKMBC models
%**  

%/* Model's spec */
%   mspec = 1: NKMBC with AR money growth  
%         = 2; NKMBC with AR money growth and sticky wage
%         = 3; NKMBC with AR money growth and sticky price
%         = 4; NKMBC with Taylor rule
%         = 5; NKMBC with Taylor rule and sticky wage
%         = 6: NKMBC with Taylor rule and sticky price
%
%    Outputs:
%       X(t) = T1*X(t-1)+T0*e(t)
%*/

% Converted from Gauss file knmod_0905.src: 06/24/06

retcode = 0;

%/* Define the model parameters
%*/


if  (spec ==1)|| (spec == 2) || (spec == 3);
   hab     = para(1);     %/* hab:   habit parameter */ 
   alp     = para(2);     %/* alp:   Deterministic growth rate */ 
   bet     = para(3);     %/* bet:   Subjective discount factor */ 
   gam     = para(4);     %/* gam:   Labour supply elasticity*/ 
   del     = para(5);     %/* del:   Depreciation rate */
   ome     = para(6);     %/* ome:   Capital adjustment costs: */
   psi     = para(7);     %/* psi:   Capital share */ 
   gm      = para(8);     %/* gm:    Money growth mean  */
   xi      = para(9);     %/* xi:    Final good demand elasticity  */
   theta   = para(10);    %/* theta: Labor demand elasticity */
   mu_p    = para(11);    %/* mu_p:  No price change probability  */
   mu_w    = para(12);    %/* mu_w:  No wage change elasticity */
   rho     = para(13);    %/* rho:   AR(1) coeff of money growth rate */
   u       = 0.1782;
   N0      = 0.9417*u;    % fixed costs of labor @% 
   
   param = [hab alp bet gam del ome psi gm xi theta mu_p mu_w rho N0]';
   
   
   %/* Determine the steady state of the stochastically
   %** detrended models
   %*/
   
   [sst,valid] = knsst(para, spec);
   
   yst = sst(1); 
   cst = sst(2); 
   ist = sst(3);
   nst = sst(4);
   kst = sst(5);
   pst = sst(6);
   mc  = sst(7);
   wage= sst(8);
   lambda= sst(9); 
   R   = sst(10);
   pi_star= sst(11);
   
   cap = 1.1739;  % Elasticity of capital utilization
   
   if (spec == 7);
      cap = 1000.1739;
   end

elseif (spec == 4) || (spec == 5) || (spec == 6) ;

   hab     = para(1);     %/* hab:   habit parameter */ 
   alp     = para(2);     %/* alp:   Deterministic growth rate */ 
   bet     = para(3);     %/* bet:   Subjective discount factor */ 
   gam     = para(4);     %/* gam:   Labour supply elasticity*/ 
   del     = para(5);     %/* del:   Depreciation rate */
   ome     = para(6);     %/* ome:   Capital adjustment costs: */
   psi     = para(7);     %/* psi:   Capital share */ 
   gm      = para(8);     %/* gm:    Money growth mean  */
   xi      = para(9);     %/* xi:    Final good demand elasticity  */
   theta   = para(10);    %/* theta: Labor demand elasticity */
   mu_p    = para(11);    %/* mu_p:  No price change probability  */
   mu_w    = para(12);    %/* mu_w:  No wage change elasticity */
   rho     = para(13);    %@Interest Rate Smoothing@
   a_pi    = para(14);    %@Taylor coefficient on expected inflation@
   a_y     = para(15);    %@Taylor coefficient on output gap@  
   u       = 0.1782;
   N0      = 0.9417*u;    % fixed costs of labor @% 
   rr      = 0.005;       %steady state real rate
   
   param = [hab alp bet gam del ome psi gm xi theta mu_p mu_w rho a_pi a_y N0 rr]';
     
   %/* Determine the steady state of the stochastically
   %** detrended models
   %*/
   
   [sst,valid] = knsst(para, spec);
   
   yst = sst(1); 
   cst = sst(2); 
   ist = sst(3);
   nst = sst(4);
   kst = sst(5);
   pst = sst(6);
   mc  = sst(7);
   wage= sst(8);
   lambda= sst(9); 
   R   = sst(10);
   gm= sst(11);
   
   cap = 1.1739;  % Elasticity of capital utilization
   
   if (spec == 8);
      cap = 1000.1739;
   end
   
else;
    valid = 1;
   
end;





if valid == 1;
   retcode = 1;
   T1 =0;
   T0 =0;
   RC = [-5;-5];
 
else;  
   
  %/* Define Matrices of canonical system  
  %*/

 
     
    
if  (spec == 1) | (spec == 2) | (spec == 3) | (spec == 7);

   
   %/*  NKMBC with Sticky Price, Sticky wage, and Variable Capital Utilization, and full indexation 
   %**      THE0*X(t) = THE1*X(t-1)+RRR*e(t)+PPI*eta(t)
   %**         1    2     3     4     5      6         7        8       9        10      11     12      
   %** X(t)=[ c(t), y(t),i(t), n(t), p(t),  pi(t)   lamda(t),  q(t),   W(t),    u(t),   mc(t),  R(t) 
   %**    13        14          15       16           17              18        19      20         21      22             
   %**   Ec(t+1), Ey(t+1),   Ei(t+1),  Epi(t+1)     Elambda(t+1),  Eq(t+1),  EW(t+1), Emc(t+1)  k(t+1), gm(t+1)
   %**       23      24      25
   %**      pi(t-1)  gm(t), epsilon(t)] 
     
    
     THE0 = zeros(25,25);
     THE1 = zeros(25,25);
     RRR  = zeros(25,2);
     PPI  = zeros(25,8);
     
  
   %**  (1) Wage Setting (labour supply)
    
     bw = ((1-bet*mu_w)*(1-mu_w))/(gam+theta);
     THE0(1,4) = bw; 
     THE0(1,5) = gam*bw;
     THE0(1,6) = -bet*mu_w;
     THE0(1,7) = -gam*bw;
     THE0(1,9) = -(1+bet*mu_w^2-theta*bw);
     THE0(1,19)= bet*mu_w;
     THE0(1,22)= bet*mu_w;
     THE0(1,23)= mu_w;
     THE0(1,24)=-mu_w*(1+bet);
     THE0(1,25)= bet*mu_w;
     THE1(1,9) = -mu_w;
     THE1(1,24) = -mu_w;
     THE1(1,25) = mu_w;
     
    
    
   %**  (2) Aggregate Resource Constraint        
            
     THE0(2,1) = cst; 
     THE0(2,2) = -yst; 
     THE0(2,3) = ist; 
     THE0(2,10) = psi*mc*yst;
     
    
   
   %**  (3) Money Growth Shock  
     
     THE0(3,22) = 1; 
     THE1(3,22) = rho;
     RRR(3,2) = 1;
     
   %**  (4) Law of motion of capital
   
     THE0(4,3) = -ist; 
     THE0(4,21) = kst;
     THE0(4,25) = (1-del)*exp(-alp)*kst; 
     THE1(4,21) = (1-del)*exp(-alp)*kst; 
     
     
   %**  (5) Production function 
     
     THE0(5,2) = -1; 
     THE0(5,4) = (1-psi)/(1-u);
     THE0(5,10) = psi;
     THE0(5,25)= -psi;
     THE1(5,21) = -psi;
     
     
     
   %**  (6) Wage (labour demand)  
     
     THE0(6,2) = 1; 
     THE0(6,4) = -1/(1-u); 
     THE0(6,5) = 1;
     THE0(6,9) = -1;
     THE0(6,11) = 1; 
    
    
   
   %**  (7) Euler equation (bond)  
     
     THE0(7,7) = 1; 
     THE0(7,12) = -1; 
     THE0(7,16) = 1;
     THE0(7,17) = -1;
     THE0(7,22) = 1;
    
     
   %**  (8) Euler Equation (Capital)  
     
     THE0(8,7) = -1; 
     THE0(8,8) = -1;
     THE0(8,14) = bet*psi*mc*yst/kst; 
     THE0(8,17) = 1;
    % THE0(8,19) = 1;
     THE0(8,18) = bet*(1-del)/exp(alp);
     THE0(8,20) = bet*psi*mc*yst/kst; 
     THE0(8,21) = -bet*psi*mc*yst/kst;
   
   %**  (9) Euler Equation (Money)  
     
     THE0(9,5) = pst/(pst+lambda); 
     THE0(9,7) = -1; 
     THE0(9,16) = -lambda/(pst+lambda);
     THE0(9,17) = lambda/(pst+lambda);
     THE0(9,22) = -1;
   
   %**  (10) Euler Equation (Habit)        
            
     THE0(10,1) = -(bet*hab^2+exp(alp)^2);
     THE0(10,7) = -(exp(alp)-hab)*(exp(alp)-bet*hab); 
     THE0(10,13) = bet*hab*exp(alp);
     THE0(10,25) = -hab*exp(alp);
     THE1(10,1) = -hab*exp(alp);
     
     
   %**  (11) Euler Equation (Investment) 
     
     THE0(11,3) = -(1+bet)*ome; 
     THE0(11,8) = 1; 
     THE0(11,15) = bet*ome;  
     THE0(11,25) = -ome;
     THE1(11,3) = -ome;
    
   
   %**  (12) Variable capital utilization  
     
     THE0(12,2) = 1; 
     THE0(12,10) = -cap;
     THE0(12,11) = 1;
     THE0(12,25) = 1;
     THE1(12,21) = 1;
   
     
     

   %**  (13) NK Phillips Curve with full indexation
     
     THE0(13,6) = -mu_p*(1+bet); 
     THE0(13,11) = (1-mu_p)*(1-bet*mu_p);
     THE0(13,16) = bet*mu_p; 
     THE0(13,22) = bet*mu_p; 
     THE0(13,24) = -mu_p*(1+bet); 
     THE0(13,25) = mu_p*(1+bet);
     THE1(13,6)  = -mu_p; 
     THE1(13,24) = -mu_p; 
     THE1(13,25) = mu_p; 
     
   
   %**  (14)  inflation rate  
     THE0(14,5) = 1;
     THE0(14,6) = -1;
     THE1(14,5) = 1;
     
   %** (15-17) Miscellaneous  
   
     % inflation rate
     THE0(15,23) = 1;
     THE1(15,6) = 1;
     
     % money growth
     THE0(16,24) = 1;
     THE1(16,22) = 1;
     
     
     % Technology shock
     THE0(17,25) = 1;
     RRR(17,1) = 1;
     
     
     
   %**  Forecast errors  
     THE0(18,1) = 1;
     THE0(19,2) = 1;
     THE0(20,3) = 1;
     THE0(21,6) = 1;
     THE0(22,7) = 1;
     THE0(23,8) = 1;
     THE0(24,9) = 1;
     THE0(25,11) = 1;
     
   
     THE1(18,13) = 1;
     THE1(19,14) = 1; 
     THE1(20,15) = 1;
     THE1(21,16) = 1;
     THE1(22,17) = 1;
     THE1(23,18) = 1;
     THE1(24,19) = 1;
     THE1(25,20) = 1;
    
     PPI(18,1) = 1;  
     PPI(19,2) = 1;
     PPI(20,3) = 1;
     PPI(21,4) = 1;
     PPI(22,5) = 1;
     PPI(23,6) = 1;
     PPI(24,7) = 1;
     PPI(25,8) = 1;
   

     
    
elseif  (spec == 4) | (spec == 5) | (spec == 6) | (spec==8) ;

   
   
   
   %/*  NKMBC with Sticky Price, Sticky wage, and Variable Capital Utilization, and full indexation 
   %**      THE0*X(t) = THE1*X(t-1)+RRR*e(t)+PPI*eta(t)
   %**         1    2     3     4     5      6         7        8       9        10      11     12      
   %** X(t)=[ c(t), y(t),i(t), n(t), p(t),  pi(t)   lamda(t),  q(t),   W(t),    u(t),   mc(t),  R(t) 
   %**    13        14          15       16           17              18        19      20         21      22             
   %**   Ec(t+1), Ey(t+1),   Ei(t+1),  Epi(t+1)     Elambda(t+1),  Eq(t+1),  EW(t+1), Emc(t+1)  k(t+1), gm(t+1)
   %**       23      24      25
   %**      pi(t-1)  gm(t), epsilon(t)] 
     
    
     THE0 = zeros(25,25);
     THE1 = zeros(25,25);
     RRR  = zeros(25,2);
     PPI  = zeros(25,8);
     
  
   %**  (1) Wage Setting (labour supply)
    
     bw = ((1-bet*mu_w)*(1-mu_w))/(gam+theta);
     THE0(1,4) = bw; 
     THE0(1,5) = gam*bw;
     THE0(1,6) = -bet*mu_w;
     THE0(1,7) = -gam*bw;
     THE0(1,9) = -(1+bet*mu_w^2-theta*bw);
     THE0(1,19)= bet*mu_w;
     THE0(1,22)= bet*mu_w;
     THE0(1,23)= mu_w;
     THE0(1,24)=-mu_w*(1+bet);
     THE0(1,25)= bet*mu_w;
     THE1(1,9) = -mu_w;
     THE1(1,24) = -mu_w;
     THE1(1,25) = mu_w;
     
    
    
   %**  (2) Aggregate Resource Constraint        
            
     THE0(2,1) = cst; 
     THE0(2,2) = -yst; 
     THE0(2,3) = ist; 
     THE0(2,10) = psi*mc*yst;
   
   %**  (3) Taylor rule  
     
     THE0(3,2)  = -(1-rho)*a_y; 
     THE0(3,12) = 1;
     THE0(3,16) = -(1-rho)*a_pi;
     THE0(3,22) = -(1-rho)*a_pi;
     THE1(3,12) = rho;
     RRR(3,2) = 1;
     
   %**  (4) Law of motion of capital
   
     THE0(4,3) = -ist; 
     THE0(4,21) = kst;
     THE0(4,25) = (1-del)*exp(-alp)*kst; 
     THE1(4,21) = (1-del)*exp(-alp)*kst; 
     
     
   %**  (5) Production function 
     
     THE0(5,2) = -1; 
     THE0(5,4) = (1-psi)/(1-u);
     THE0(5,10) = psi;
     THE0(5,25)= -psi;
     THE1(5,21) = -psi;
     
     
     
   %**  (6) Wage (labour demand)  
     
     THE0(6,2) = 1; 
     THE0(6,4) = -1/(1-u); 
     THE0(6,5) = 1;
     THE0(6,9) = -1;
     THE0(6,11) = 1; 
    
   
   %**  (7) Euler equation (bond)  
     
     THE0(7,7) = 1; 
     THE0(7,12) = -1; 
     THE0(7,16) = 1;
     THE0(7,17) = -1;
     THE0(7,22) = 1;
    
     
   %**  (8) Euler Equation (Capital)  
     
     THE0(8,7) = -1; 
     THE0(8,8) = -1;
     THE0(8,14) = bet*psi*mc*yst/kst; 
     THE0(8,17) = 1;
    % THE0(8,19) = 1;
     THE0(8,18) = bet*(1-del)/exp(alp);
     THE0(8,20) = bet*psi*mc*yst/kst; 
     THE0(8,21) = -bet*psi*mc*yst/kst;
   
   %**  (9) Euler Equation (Money)  
     
     THE0(9,5) = pst/(pst+lambda); 
     THE0(9,7) = -1; 
     THE0(9,16) = -lambda/(pst+lambda);
     THE0(9,17) = lambda/(pst+lambda);
     THE0(9,22) = -1;
   
   %**  (10) Euler Equation (Habit)        
            
     THE0(10,1) = -(bet*hab^2+exp(alp)^2);
     THE0(10,7) = -(exp(alp)-hab)*(exp(alp)-bet*hab); 
     THE0(10,13) = bet*hab*exp(alp);
     THE0(10,25) = -hab*exp(alp);
     THE1(10,1) = -hab*exp(alp);
     
     
   %**  (11) Euler Equation (Investment) 
     
     THE0(11,3) = -(1+bet)*ome; 
     THE0(11,8) = 1; 
     THE0(11,15) = bet*ome;  
     THE0(11,25) = -ome;
     THE1(11,3) = -ome;
    
   
   %**  (12) Variable capital utilization  
     
     THE0(12,2) = 1; 
     THE0(12,10) = -cap;
     THE0(12,11) = 1;
     THE0(12,25) = 1;
     THE1(12,21) = 1;
   
     

   %**  (13) NK Phillips Curve with full indexation
     
     THE0(13,6) = -mu_p*(1+bet); 
     THE0(13,11) = (1-mu_p)*(1-bet*mu_p);
     THE0(13,16) = bet*mu_p; 
     THE0(13,22) = bet*mu_p; 
     THE0(13,24) = -mu_p*(1+bet); 
     THE0(13,25) = mu_p*(1+bet);
     THE1(13,6)  = -mu_p; 
     THE1(13,24) = -mu_p; 
     THE1(13,25) = mu_p; 
     
   
   %**  (14)  inflation rate  
     THE0(14,5) = 1;
     THE0(14,6) = -1;
     THE1(14,5) = 1;
     
   %** (15-17) Miscellaneous  
   
     % inflation rate
     THE0(15,23) = 1;
     THE1(15,6) = 1;
     
     % money growth
     THE0(16,24) = 1;
     THE1(16,22) = 1;
     
     
     % Technology shock
     THE0(17,25) = 1;
     RRR(17,1) = 1;
     
     
     
   %**  Forecast errors  
     THE0(18,1) = 1;
     THE0(19,2) = 1;
     THE0(20,3) = 1;
     THE0(21,6) = 1;
     THE0(22,7) = 1;
     THE0(23,8) = 1;
     THE0(24,9) = 1;
     THE0(25,11) = 1;
     
   
     THE1(18,13) = 1;
     THE1(19,14) = 1; 
     THE1(20,15) = 1;
     THE1(21,16) = 1;
     THE1(22,17) = 1;
     THE1(23,18) = 1;
     THE1(24,19) = 1;
     THE1(25,20) = 1;
    
     PPI(18,1) = 1;  
     PPI(19,2) = 1;
     PPI(20,3) = 1;
     PPI(21,4) = 1;
     PPI(22,5) = 1;
     PPI(23,6) = 1;
     PPI(24,7) = 1;
     PPI(25,8) = 1;
   
     
   
   end;
   
   
   
    [neq,junk] = size(THE0);
    Const    = zeros(neq,1);


   %/* Sims's QZ Algorism */
  
   [T1,TC,T0,TY,M,TZ,GEV,RC] = gensys(THE0, THE1, Const, RRR, PPI);
   
   
   
end;




