function [sst,valid] = knsst(para, spec);
%/* knsst.m: calculating the steady states of NKMBC models
%/* Modified: 05/10/2009
%/* To match the first moments [mean(C/Y) mean(N) mean(R) mean(inflation)] 
%/* Need nonlinear solver

%/* Model's spec */
%   mspec = 1: NKMBC with AR money growth  
%         = 2; NKMBC with AR money growth and flexible price
%         = 3; NKMBC with AR money growth and flexible wage
%         = 4; NKMBC with Taylor rule
%         = 5; NKMBC with Taylor rule and flexible price
%         = 6: NKMBC with Taylor rule and flexible wage



%/* assign names to parameters
%*/


if  (spec ==1)|| (spec == 2) || (spec == 3) ;
   hab     = para(1);     %/* hab:   habit parameter */ 
   alp     = para(2);     %/* alp:   Deterministic growth rate */ 
   bet     = para(3);     %/* bet:   Subjective discount factor */ 
   gam     = para(4);     %/* gam:   Labour supply elasticity*/ 
   del     = para(5);     %/* del:   Depreciation rate */
   ome     = para(6);     %/* ome:   Capital adjustment costs: */
   psi     = para(7);     %/* psi:   Capital share */ 
   gm      = para(8);     %/* gm:    Money growth mean  */
   xi      = para(9);     %/* xi:    Final good demand elasticity  */
   theta   = para(10);    %/* theta: Labor demand elasticity */
   mu_p    = para(11);    %/* mu_p:  No price change probability  */
   mu_w    = para(12);    %/* mu_w:  No wage change elasticity */
   rho     = para(13);    %/* rho:   AR(1) coeff of money growth rate */
   u       = 0.1782;
   N0      = 0.9417*u;    % fixed costs of labor @% 
   
   
   param = [hab alp bet gam del ome psi gm xi theta mu_p mu_w rho N0]';

elseif (spec == 4) || (spec == 5) || (spec == 6)  ;

   hab     = para(1);     %/* hab:   habit parameter */ 
   alp     = para(2);     %/* alp:   Deterministic growth rate */ 
   bet     = para(3);     %/* bet:   Subjective discount factor */ 
   gam     = para(4);     %/* gam:   Labour supply elasticity*/ 
   del     = para(5);     %/* del:   Depreciation rate */
   ome     = para(6);     %/* ome:   Capital adjustment costs: */
   psi     = para(7);     %/* psi:   Capital share */ 
   gm      = para(8);     %/* gm:    Money growth mean  */
   xi      = para(9);     %/* xi:    Final good demand elasticity  */
   theta   = para(10);    %/* theta: Labor demand elasticity */
   mu_p    = para(11);    %/* mu_p:  No price change probability  */
   mu_w    = para(12);    %/* mu_w:  No wage change elasticity */
   rho     = para(13);    %@Interest Rate Smoothing@
   a_pi    = para(14);    %@Taylor coefficient on expected inflation@
   a_y     = para(15);    %@Taylor coefficient on output gap@  
   u       = 0.1782;
   N0      = 0.9417*u;    % fixed costs of labor @% 
   rr      = 0.005;       %steady state real rate
   
   param = [hab alp bet gam del ome psi gm xi theta mu_p mu_w rho a_pi a_y N0 rr]';
   
else;
    valid = 1;
   
end;

gst = exp(alp);

 

  %/* Initialize Output Variables
  %*/
  valid = 0;
  
  mc  = (xi-1)/xi;                    %(N1.8)
  i_k = 1-(1-del)/gst;                %(N1.10)
  rate = 1/bet - (1-del)/exp(alp);    %(N1.3)
  y_k = rate/(mc*psi);                %(N1.3)
  k_Ndev = (y_k*gst^psi)^(1/(psi-1)); %(N1.12)
  y_Ndev = y_k*k_Ndev;
  i_y = i_k/y_k;
  c_y = 1-i_y;                        %(N1.11)
  wage= (1-psi)*mc*y_Ndev;            %(N1.7)
 
  %[nst,fval,exitflag,output]  = fzero(@ssn,0.99)     % Nonlinear solution of ss labor
  %ssn(nst)
  
  [nst,fval,flag] = runssn(0.99,param,spec);
  
  if (flag == 1)
  
  yst = y_Ndev*(nst-N0);
  kst = k_Ndev*(nst-N0);
  ist = i_y*yst;
  cst = c_y*yst;
  lam1 = (1-bet*hab/gst)/((1-hab/gst)*cst);
  pst = (1-bet*exp(-gm))*lam1/(bet*exp(-gm));
  R = exp(gm)/bet;
  pi = gm-alp;
  
    if(spec == 4)
     
       gm = (rr-alp*a_pi+log(bet))/(1-a_pi);
       R = exp(gm)/bet;
       pi = gm - alp;
 
    end
 
  sst = [yst ; cst ; ist ; nst ; kst ; pst ; mc ; wage ; lam1; R; gm]; 
  
  else
      sst = zeros(11,1);
      valid = 1;
  
  end
  
  
  


 
 