function [dens,xpts] = ndens(xv,npts,nobs) 

%@ ----- Compute the Normal Kernal ----- @

   alph = 0.5 ;
   dens = zeros(npts+1,1) ;
      b = zeros(2,1) ;
      n = nobs ;
    ad1 = sqrt( 1/(2*pi) ) ;

%@ ----- Compute Adaptive Estimate of Spread ----- @
%@ -----   as in Silverman, p.47, eq. 3.30   ----- @

     r1 = min( xv ) ;  r2 = max( xv ) ;
  range = r2 - r1 ;    inc = range/npts ;

%@     r1~r2~inc ;@

   xpts = seqa(r1,inc,npts+1); 
     x1 = sort(xv,1) ;
   stdx = std( xv ) ; ann = n^(-0.2) ;

     q1 = round( n/4 ) ;  q2 = round( 3*n/4 ) ;
      r = x1(q2,:) - x1(q1,:);
     b(1,1) = stdx ;   b(2,1) = r/1.34 ;
      a = min( b ) ;

%@ -----   Compute Automatic Bandwidth   ----- @
%@ ----- as in Silverman, p.48, eq. 3.31 ----- @

      h = 0.9*a*ann ;
      j = 1 ;
      while j <= npts + 1 ;
         xbar = xpts(j,:);
         wn = weightn(xv,xbar,h,ad1) ;
         dens(j,:) = (1/(n*h))*sum( wn ) ;
         j = j + 1 ;
      end;

%@     dens = missrv(dens,0) ;
%      dens = delif(dens,dens[.,1].==0) ;
%      if rows(dens) < 500 ;
%         densn[.,1] = dens|zeros(npts - rows(dens),1) ;
%      else ;
%         densn[.,1] = dens ;
%      endif ;@




function [ti] = seqa(start,inc,no)

 ti = zeros(no,1);
 ti(1) = start;
 for i = 2:no;
    ti(i) = ti(i-1)+inc;
 end

end


function [weight] = weightn(x,xbar,h,ad1) 

%@ ----- computes wts for normal kernel ----- @

     
     w = exp( -0.5.*( ((x - xbar)./h).*((x - xbar)./h) ) ) ;

     weight = ad1*w;

end




end