function [nst,fval,flag] = runssn(x0,param,spec);
% runssn.m: solving nonlinear equation system to find the steady states


 if  (spec ==1)||(spec ==2)||(spec==3);
    
   hab     = param(1);     %/* hab:   habit parameter */ 
   alp     = param(2);     %/* alp:   Deterministic growth rate */ 
   bet     = param(3);     %/* bet:   Subjective discount factor */ 
   gam     = param(4);     %/* gam:   Labour supply elasticity*/ 
   del     = param(5);     %/* del:   Depreciation rate */
   ome     = param(6);     %/* ome:   Capital adjustment costs: */
   psi     = param(7);     %/* psi:   Capital share */ 
   gm      = param(8);     %/* gm:    Money growth mean  */
   xi      = param(9);     %/* xi:    Final good demand elasticity  */
   theta   = param(10);    %/* theta: Labor demand elasticity */
   mu_p    = param(11);    %/* mu_p:  No price change probability  */
   mu_w    = param(12);    %/* mu_w:  No wage change elasticity */
   rho     = param(13);    %/* rho:   AR(1) coeff of money growth rate */
   N0      = param(14);    % fixed costs of labor @% 

 elseif (spec == 4)||(spec == 5)||(spec == 6);

   hab     = param(1);     %/* hab:   habit parameter */ 
   alp     = param(2);     %/* alp:   Deterministic growth rate */ 
   bet     = param(3);     %/* bet:   Subjective discount factor */ 
   gam     = param(4);     %/* gam:   Labour supply elasticity*/ 
   del     = param(5);     %/* del:   Depreciation rate */
   ome     = param(6);     %/* ome:   Capital adjustment costs: */
   psi     = param(7);     %/* psi:   Capital share */ 
   gm      = param(8);     %/* gm:    Money growth mean  */
   xi      = param(9);     %/* xi:    Final good demand elasticity  */
   theta   = param(10);    %/* theta: Labor demand elasticity */
   mu_p    = param(11);    %/* mu_p:  No price change probability  */
   mu_w    = param(12);    %/* mu_w:  No wage change elasticity */
   rho     = param(13);    %@Interest Rate Smoothing@
   a_pi    = param(14);    %@Taylor coefficient on expected inflation@
   a_y     = param(15);    %@Taylor coefficient on output gap@  
   N0      = param(16);    % fixed costs of labor @% 
   rr      = param(17);    %steady state real rate

 else;
    valid = 1;
 
 end;


 gst = exp(alp);
 
 [nst,fval,flag]  = fzero(@ssn,x0);     % Nonlinear solution of ss labor

  function f = ssn(x);


  %/* Initialize Output Variables
  %*/
  valid = 0;
  
  mc  = (xi-1)/xi;                    %(N1.8)
  i_k = 1-(1-del)/gst;                %(N1.10)
  rate = 1/bet - (1-del)/exp(alp);    %(N1.3)
  y_k = rate/(mc*psi);                %(N1.3)
  k_Ndev = (y_k*gst^psi)^(1/(psi-1)); %(N1.12)
  y_Ndev = y_k*k_Ndev;
  i_y = i_k/y_k;
  c_y = 1-i_y;                        %(N1.11)
  wage= (1-psi)*mc*y_Ndev;            %(N1.7)
  nbar = (theta/(theta-1))*c_y*(gst-hab)/(gst-bet*hab); 
  nbar = nbar/(mc*(1-psi));
  nstar = nbar^-1/(1+1/gam);
  
  
  f = nbar*(x-N0)-x^(-1/gam);
  
end

end

  
  