%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  kn_bvar.m
%  
%    Bayesian VAR Estimation by BACC
%   
%  Creadted: June 23, 2006
%  Modified: August 21, 2007
%            July 24, 2009
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear ; 
clc;

% Mainpath
pathspec;

mainpath = [mainpath '\spec0'];


%***************************  Loading Data *******************************%

    load kn_data.dat; %1954:Q1-2002:Q4: No of sample 196
    data = kn_data;
    
  % Y, C, I, G, P, N, M

           Y = data(:,1);
           C = data(:,2);
           I = data(:,3);
           G = data(:,4);
           P = data(:,5);
           N = data(:,6);
           M = data(:,7);
           
           Y = C + I;
           
           [nobs,junk] = size(Y);
           
           DY = log(Y(2:nobs))-log(Y(1:nobs-1));
           DC = log(C(2:nobs))-log(C(1:nobs-1));
           DI = log(I(2:nobs))-log(I(1:nobs-1));
           DG = log(G(2:nobs))-log(G(1:nobs-1));
           DP = log(P(2:nobs))-log(P(1:nobs-1));
           DM = log(M(2:nobs))-log(M(1:nobs-1));
           N  = log(N(2:nobs));
           
           DY = 400.*DY;
           DC = 400.*DC;
           DI = 400.*DI;
           DG = 400.*DG;
           DP = 400.*DP;
           DM = 400.*DM;
           N  = 400.*N;
           
   
 %% /* Sample estimates of the SDs of the IRFs           
           
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   % Information sets
   % infospec  
   %           = 1: [DlnY DlnP]
   %           = 2: [DlnC DlnP]
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
           
   infospec = 1; 
   varlag = 2;
           
           if infospec == 1;
               Info = [DY DP]; lags = varlag;
           elseif infospec == 2;
               Info = [DC DP]; lags = varlag;
           end;
           
           
           xtilde = VARData(Info,lags);   % Call VARData
           [nobs,cols] = size(xtilde);
           DepData = xtilde(:,1:2);
           IndData = [xtilde(:,3:cols) ones(nobs,1)];
           Beta = inv(IndData'*IndData)*IndData'*DepData;
           Resid = DepData - IndData*Beta;
           VCOV  = Resid'*Resid./nobs;
           VCOV_Beta = kron(VCOV,inv(IndData'*IndData));
           SE_Beta = sqrt(diag(VCOV_Beta));
     
           
           
    %********** Estimating the sample estimates of the IRFs **************%      
           horizon = 41;
           IMPL11 = zeros(horizon,1);
           IMPL12 = zeros(horizon,1);
        
        % BQ long-run decomposition code by Jim: revised 08/02/06 
            
           [c00, smimp1, smimp2, smimpl1, smimpl2] ...
                           = bqdecomp(Beta(1:2*lags,:), VCOV, eye(2),lags,nobs);  
           IMPL11(:,1)=smimpl1(1:horizon,1)'; % Accumulated IRF of lnY or lnC to a permanent shock
           IMPL12(:,1)=smimpl1(1:horizon,2)'; % Accumulated IRF of lnY or lnC to a transitory shock
           IMPL11g = smimp1(1:horizon,1);
           IMPL12g = smimp1(1:horizon,2);
           IMPL21=smimp2(1:horizon,1)';
           IMPL22=smimp2(1:horizon,2)';    
           
          
          savefile = [mainpath '\info' num2str(infospec) '\VAR' num2str(varlag) '\sample_impl11.mat'];
          save(savefile,'IMPL11','-ascii');  
          savefile = [mainpath '\info' num2str(infospec) '\VAR' num2str(varlag) '\sample_impl12.mat'];
          save(savefile,'IMPL12','-ascii');   
           
          
         
    %******* Estimating the sample estimates of the SDs the IRFs *********%    
    
         IMPL_SPECT_40_p = zeros(314,1);
         IMPL_SPECT_12_p = zeros(314,1);
         IMPL_SPECT_20_p = zeros(314,1);

         IMPL_SPECT_40_t = zeros(314,1);
         IMPL_SPECT_12_t = zeros(314,1);
         IMPL_SPECT_20_t = zeros(314,1);
        
         IMPL_SPECT_INF_40_p = zeros(314,1);
         IMPL_SPECT_INF_40_t = zeros(314,1);
         

        
         IMPL_SPECT_40_p(1,1) = real(svmaspect(0,smimp1(:,1),40));
         IMPL_SPECT_12_p(1,1) = real(svmaspect(0,smimp1(:,1),12));
         IMPL_SPECT_20_p(1,1) = real(svmaspect(0,smimp1(:,1),20));
     
           for j = 2:314;
             omega = j/100;
             IMPL_SPECT_40_p(j,1) = real(svmaspect(omega,smimp1(:,1),40));
             IMPL_SPECT_12_p(j,1) = real(svmaspect(omega,smimp1(:,1),12));
             IMPL_SPECT_20_p(j,1) = real(svmaspect(omega,smimp1(:,1),20));
           end; 
    
      
           
         IMPL_SPECT_40_t(1,1) = real(svmaspect(0,smimp1(:,2),40));
         IMPL_SPECT_12_t(1,1) = real(svmaspect(0,smimp1(:,2),12));
         IMPL_SPECT_20_t(1,1) = real(svmaspect(0,smimp1(:,2),20));
     
          for j = 2:314;
            omega = j/100;
             IMPL_SPECT_40_t(j,1) = real(svmaspect(omega,smimp1(:,2),40));
             IMPL_SPECT_12_t(j,1) = real(svmaspect(omega,smimp1(:,2),12));
             IMPL_SPECT_20_t(j,1) = real(svmaspect(omega,smimp1(:,2),20));
          end;   
         
          
         IMPL_SPECT_INF_40_p(1,1) = real(svmaspect(0,smimp2(:,1),40));
         
     
           for j = 2:314;
             omega = j/100;
             IMPL_SPECT_INF_40_p(j,1) = real(svmaspect(omega,smimp2(:,1),40));
           end; 
    
      
           
         IMPL_SPECT_INF_40_t(1,1) = real(svmaspect(0,smimp2(:,2),40));
        
     
          for j = 2:314;
            omega = j/100;
             IMPL_SPECT_INF_40_t(j,1) = real(svmaspect(omega,smimp2(:,2),40));
            
          end;   
          
          savefile = [mainpath '\info' num2str(infospec) '\VAR' num2str(varlag) '\sample_impl_spect_40_p.mat'];
          save(savefile,'IMPL_SPECT_40_p','-ascii');  
          savefile = [mainpath '\info' num2str(infospec) '\VAR' num2str(varlag) '\sample_impl_spect_12_p.mat'];
          save(savefile,'IMPL_SPECT_12_p','-ascii');        
          savefile = [mainpath '\info' num2str(infospec) '\VAR' num2str(varlag) '\sample_impl_spect_20_p.mat'];
          save(savefile,'IMPL_SPECT_20_p','-ascii');  
          savefile = [mainpath '\info' num2str(infospec) '\VAR' num2str(varlag) '\sample_impl_spect_40_t.mat'];
          save(savefile,'IMPL_SPECT_40_t','-ascii');  
          savefile = [mainpath '\info' num2str(infospec) '\VAR' num2str(varlag) '\sample_impl_spect_12_t.mat'];
          save(savefile,'IMPL_SPECT_12_t','-ascii');        
          savefile = [mainpath '\info' num2str(infospec) '\VAR' num2str(varlag) '\sample_impl_spect_20_t.mat'];
          save(savefile,'IMPL_SPECT_20_t','-ascii');  
          
          savefile = [mainpath '\info' num2str(infospec) '\VAR' num2str(varlag) '\sample_impl_spect_INF_40_p.mat'];
          save(savefile,'IMPL_SPECT_INF_40_p','-ascii');  
          
          savefile = [mainpath '\info' num2str(infospec) '\VAR' num2str(varlag) '\sample_impl_spect_INF_40_t.mat'];
          save(savefile,'IMPL_SPECT_INF_40_t','-ascii');  
          
       
          
          
    %% /* Posterior simulation of BVAR by BACC      
          
     %/*************** Set parameters for BACC ***************************/
     
          Beta_bar  = [Beta(:,1);Beta(:,2)];
          Beta_pres = inv(VCOV_Beta);
          p = 2*lags+1;
          Nu        = p;      % corrected the degree of freedom 09/21/06
          S_bar     = inv(VCOV);
          
          ZMat      = kron(eye(2),IndData);
          YMat      = [DepData(:,1);DepData(:,2)];
          
          %whitcov = inv(ZMat'*ZMat)*ZMat'*kron(VCOV, eye(nobs))*ZMat*inv(ZMat'*ZMat) ;
%         Beta_pres = inv(whitcov) ;

          xresid1 = Resid(:,1) ;
          xresid2 = Resid(:,2) ;
          for i = (2*lags):-1:1 ;
              xresid1 = [Resid(:,1).*IndData(:,i) xresid1] ;
              xresid2 = [Resid(:,2).*IndData(:,i) xresid2]  ;
          end ;
          xresid = [xresid1 xresid2] ;
          sss = Bartwin(xresid, xresid'*xresid, nobs) ;
          nwcov = inv( (ZMat'*ZMat)*inv(sss)*(ZMat'*ZMat) ) ;
          Beta_pres = inv(nwcov);
          
             
     %
     % Create model instance
     %
     
         VAR = minst('nlm', 'beta_sim', 'hhh_sim', Beta_bar, Beta_pres, Nu, S_bar, ZMat, YMat) ;
         sreps = 10000 ;         
     %
     %   Simulate 10000 prior samples
     %
         setSeedConstant ;
         priorsim(VAR,sreps,1) ;
     %
     %   Simulate 2000 posterior samples
     %
         setSeedConstant ;
         postsim(VAR,0.2*sreps,1) ;
     %
     %   Filter out the first 1000 posterior samples
     %
          ffii = [1001:0.2*sreps] ;
          postfilter(VAR,ffii) ;
     %
     %   Add 5000 new posterior samples
     %
         setSeedConstant ;
         postsim(VAR,sreps*0.5,1) ;
    
     %
     %   Add 10000 new HM posterior samples
     %
         setSeedConstant ;
         postsimHM(VAR,sreps,1,5) ;      
     
     %
     %  Extract the vector of posterior samples of the elements of beta
     %
        VAR_sim = extract(VAR) ;
        Beta_sim = squeeze(VAR_sim.beta_sim(:,1,:))' ;
        HHH_sim_1  = squeeze(VAR_sim.hhh_sim(:,1,:))' ;
        HHH_sim_2  = squeeze(VAR_sim.hhh_sim(:,2,:))' ;
     %   for i = 1:24;
     %    expect1(VAR_sim.logWeightPost,VAR_sim.beta_sim(i,1,:))
     %   end;
        
        simbeta = [Beta_sim HHH_sim_1 HHH_sim_2] ;

    
     savefile = [mainpath '\info' num2str(infospec) '\VAR' num2str(varlag) '\bvar.mat'];
     save(savefile,'simbeta','-ascii');   
     
     
    
        