%/*************************************************************************
%**  
%**  This program derives the CvM statistics of the SDs 
%**    NKMBCs with money growth rate rule (spec = 1,2,3)
%**    Transitory shocks
%**  
%**************************************************************************/

%/* filename:  kn_cvm_sd_ar_t.m
%** created:  07/05/07
%** 
%*/

clear;
clc

%/* Set the path */
pathspec;


support = [0:0.1:10];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Information sets
% infospec 
%           = 1: [DlnY DlnP]
%           = 2: [DlnC DlnP]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%          
infospec = 2;   


%/* VAR lag length */
varlag = 2;


%% /* Model spec 1*/
mspec = 1;


  %/**************** Loading SDMs of IRFs of DlnY or DlnC ******************/
 
  
  % Transitory Shocks 40 lags
   % Empirical
    loadsdm = [mainpath '\spec0\info' num2str(infospec) '\VAR' num2str(varlag) '\impl_spect_40_t.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_t_0 = impl_spect_40_t;
    impl_spect_40_t_0 = sortrows(impl_spect_40_t_0',1);
    impl_spect_40_t_0 = impl_spect_40_t_0(10:4990,:)';
   
  
   % Theoretical Non-Habit
  
    loadsdm = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\impl_spect_40_t.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_t_1 = impl_spect_40_t;
    impl_spect_40_t_1 = sortrows(impl_spect_40_t_1',1)';
    %impl_spect_40_t_1 = impl_spect_40_t_1(10:4990,:)';
   
 
   % Theoretical Habit
  
    loadsdm = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\habit\impl_spect_40_t.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_t_1h = impl_spect_40_t;
   impl_spect_40_t_1h = sortrows(impl_spect_40_t_1h',1)';
    %impl_spect_40_t_1h = impl_spect_40_t_1h(10:4990,:)';
   
  
    % Sample
    
    loadsdm = [mainpath '\spec0\info' num2str(infospec) '\VAR' num2str(varlag) '\sample_impl_spect_40_t.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_t_s = sample_impl_spect_40_t;
    
    
  
  %/**************** Calculating KS statistics for whole frequency range ******************/
    
     [KS0,CVM0]=kscvm(impl_spect_40_t_0,impl_spect_40_t_s,1,98);
     [KS1,CVM1]=kscvm(impl_spect_40_t_1,impl_spect_40_t_s,1,98);
     [KS1h,CVM1h]=kscvm(impl_spect_40_t_1h,impl_spect_40_t_s,1,98);
  
  
    %/* Calculating CIC */
     CIC1_1=cic(CVM0, CVM1, 95);
     CIC1h_1=cic(CVM0, CVM1h, 95);
  
    %/* Printing CICs */ 
     disp(sprintf('baseline whole: CIC of non-habit:   %10.3f', CIC1_1 ));
     disp(sprintf('baseline whole: CIC of habit:   %10.3f', CIC1h_1 ));
  
   %/* Nonparametric kernel density estimation of CVM */
   
     np=1000;
     ndrop0 = 10;
     ndrop1 = 10;
     ndrop2 = 10;
  
     CVMMAT0 = sort(CVM0,1);
     CVMMAT1 = sort(CVM1,1);
     CVMMAT1h = sort(CVM1h,1);
    
     [ndraw,junk] = size(CVM0);
   
     [YY0_1,XX0_1]=ndens(CVMMAT0(1:ndraw-ndrop0),100,ndraw-ndrop0);
     [YY1_1,XX1_1]=ndens(CVMMAT1(1:5000-ndrop1,1),100,5000-ndrop1);
     [YY1h_1,XX1h_1]=ndens(CVMMAT1h(1:5000-ndrop2,1),100,5000-ndrop2);
   
     npCVM_sirf_whole_t = [YY0_1 XX0_1 YY1_1 XX1_1 YY1h_1 XX1h_1];

     
     
  %/**************** Calculating CVM statistics for business cycle frequencies between 8 years and 2 years per cycle ******************/
    
     [KS0,CVM0]=kscvm(impl_spect_40_t_0,impl_spect_40_t_s,6,24);
     [KS1,CVM1]=kscvm(impl_spect_40_t_1,impl_spect_40_t_s,6,24);
     [KS1h,CVM1h]=kscvm(impl_spect_40_t_1h,impl_spect_40_t_s,6,24);
   
     
    %/* Calculating CIC */
     CIC1_2=cic(CVM0, CVM1, 95);
     CIC1h_2=cic(CVM0, CVM1h, 95);
  
  
    %/* Printing CICs */ 
     disp(sprintf('baseline BC: CIC of non-habit:   %10.3f', CIC1_2 ));
     disp(sprintf('baseline BC: CIC of habit:   %10.3f', CIC1h_2 ));
  
  
   
   %/* Nonparametric kernel density estimation of CVM */
     np=1000;
     ndrop0 = 10;
     ndrop1 = 10;
     ndrop2 = 10;
  
     CVMMAT0 = sort(CVM0,1);
     CVMMAT1 = sort(CVM1,1);
     CVMMAT1h = sort(CVM1h,1);
    
  
     [ndraw,junk] = size(CVM0);
     
     [YY0_2,XX0_2]=ndens(CVMMAT0(1:ndraw-ndrop0),100,ndraw-ndrop0);
     [YY1_2,XX1_2]=ndens(CVMMAT1(1:5000-ndrop1,1),100,5000-ndrop1);
     [YY1h_2,XX1h_2]=ndens(CVMMAT1h(1:5000-ndrop2,1),100,5000-ndrop2);
   
     npCVM_sirf_8to2_t = [YY0_2 XX0_2 YY1_2 XX1_2 YY1h_2 XX1h_2];
    
     
     
  %/**************** Mean and Median SDMs of IRFs of DlnY ******************/
     mean_1 = [mean(impl_spect_40_t_0')' mean(impl_spect_40_t_1')' mean(impl_spect_40_t_1h')'];
     median_1 = [median(impl_spect_40_t_0')' median(impl_spect_40_t_1')' median(impl_spect_40_t_1h')'];
     
    
  
  %/**************** Summing up the CICs ******************/   
     cic_mat = [CIC1_1; CIC1h_1; CIC1_2; CIC1h_2];
     
   
  
  %/**************** Saving the results ******************/   
     if infospec == 1; 
     
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\npCVM_sirf_whole_y_t.mat'];
       save(savefile,'npCVM_sirf_whole_t','-ascii'); 
    
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\npCVM_sirf_8to2_y_t.mat'];
       save(savefile,'npCVM_sirf_8to2_t','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\meanCVM_sirf_y_t.mat'];
       save(savefile,'mean_1','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\cicCVM_y_t.mat'];
       save(savefile,'cic_mat','-ascii'); 
     
  
    
    elseif infospec == 2;
        
    
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\npCVM_sirf_whole_c_t.mat'];
       save(savefile,'npCVM_sirf_whole_t','-ascii'); 
    
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\npCVM_sirf_8to2_c_t.mat'];
       save(savefile,'npCVM_sirf_8to2_t','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\meanCVM_sirf_c_t.mat'];
       save(savefile,'mean_1','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\cicCVM_c_t.mat'];
       save(savefile,'cic_mat','-ascii'); 
    
  
    end
     
     
     
     
     
%% /* Model spec 2*/
mspec = 2;

  %/**************** Loading SDMs of IRFs of DlnY or DlnC ******************/
 
  % Transitory Shocks 40 lags
   % Empirical
    loadsdm = [mainpath '\spec0\info' num2str(infospec)  '\VAR' num2str(varlag) '\impl_spect_40_t.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_t_0 = impl_spect_40_t;
    impl_spect_40_t_0 = sortrows(impl_spect_40_t_0',1);
    impl_spect_40_t_0 = impl_spect_40_t_0(10:4990,:)';
   
  
   % Theoretical Non-Habit
  
    loadsdm = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec)  '\VAR' num2str(varlag) '\impl_spect_40_t.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_t_1 = impl_spect_40_t;
    impl_spect_40_t_1 = sortrows(impl_spect_40_t_1',1)';
    %impl_spect_40_t_1 = impl_spect_40_t_1(10:4990,:)';
   
 
   % Theoretical Habit
  
    loadsdm = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec)  '\VAR' num2str(varlag) '\habit\impl_spect_40_t.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_t_1h = impl_spect_40_t;
   impl_spect_40_t_1h = sortrows(impl_spect_40_t_1h',1)';
    %impl_spect_40_t_1h = impl_spect_40_t_1h(10:4990,:)';
   
  
    % Sample
    
    loadsdm = [mainpath '\spec0\info' num2str(infospec)  '\VAR' num2str(varlag) '\sample_impl_spect_40_t.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_t_s = sample_impl_spect_40_t;
    
  
  %/**************** Calculating CVM statistics for whole frequency range ******************/
    
     [KS0,CVM0]=kscvm(impl_spect_40_t_0,impl_spect_40_t_s,1,98);
     [KS1,CVM1]=kscvm(impl_spect_40_t_1,impl_spect_40_t_s,1,98);
     [KS1h,CVM1h]=kscvm(impl_spect_40_t_1h,impl_spect_40_t_s,1,98);
   
  
    %/* Calculating CIC */
     CIC1_1=cic(CVM0, CVM1, 95);
     CIC1h_1=cic(CVM0, CVM1h, 95);
  
  
    %/* Printing CICs */ 
     disp(sprintf('SW whole: CIC of non-habit:   %10.3f', CIC1_1 ));
     disp(sprintf('SW whole: CIC of habit:   %10.3f', CIC1h_1 ));
  
 
   %/* Nonparametric kernel density estimation of CVM */
     np=1000;
     ndrop0 = 10;
     ndrop1 = 10;
     ndrop2 = 10;
  
     CVMMAT0 = sort(CVM0,1);
     CVMMAT1 = sort(CVM1,1);
     CVMMAT1h = sort(CVM1h,1);
 
  
     [ndraw,junk] = size(CVM0);
   
   
     [YY0_1,XX0_1]=ndens(CVMMAT0(1:ndraw-ndrop0),100,ndraw-ndrop0);
     [YY1_1,XX1_1]=ndens(CVMMAT1(1:5000-ndrop1,1),100,5000-ndrop1);
     [YY1h_1,XX1h_1]=ndens(CVMMAT1h(1:5000-ndrop2,1),100,5000-ndrop2);
   
     
     npCVM_sirf_whole_t = [YY0_1 XX0_1 YY1_1 XX1_1 YY1h_1 XX1h_1];

     
     
  %/**************** Calculating CVM statistics for business cycle frequencies between 8 years and 2 years per cycle ******************/
     [KS0,CVM0]=kscvm(impl_spect_40_t_0,impl_spect_40_t_s,6,24);
     [KS1,CVM1]=kscvm(impl_spect_40_t_1,impl_spect_40_t_s,6,24);
     [KS1h,CVM1h]=kscvm(impl_spect_40_t_1h,impl_spect_40_t_s,6,24);
   
    
    %/* Calculating CIC */
     CIC1_2=cic(CVM0, CVM1, 95);
     CIC1h_2=cic(CVM0, CVM1h, 95);
  
  
    %/* Printing CICs */ 
     disp(sprintf('SW BC: CIC of non-habit:   %10.3f', CIC1_2 ));
     disp(sprintf('SW BC: CIC of habit:   %10.3f', CIC1h_2 ));
  
  
   %/* Nonparametric kernel density estimation of CVM */
     np=1000;
     ndrop0 = 10;
     ndrop1 = 10;
     ndrop2 = 10;
  
     CVMMAT0 = sort(CVM0,1);
     CVMMAT1 = sort(CVM1,1);
     CVMMAT1h = sort(CVM1h,1);
   
  
     [ndraw,junk] = size(CVM0);
   
   
     [YY0_2,XX0_2]=ndens(CVMMAT0(1:ndraw-ndrop0),100,ndraw-ndrop0);
     [YY1_2,XX1_2]=ndens(CVMMAT1(1:5000-ndrop1,1),100,5000-ndrop1);
     [YY1h_2,XX1h_2]=ndens(CVMMAT1h(1:5000-ndrop2,1),100,5000-ndrop2);
   
      npCVM_sirf_8to2_t = [YY0_2 XX0_2 YY1_2 XX1_2 YY1h_2 XX1h_2];
    
     
     
     
  %/**************** Mean and Median SDMs of IRFs of DlnY ******************/
     mean_1 = [mean(impl_spect_40_t_0')' mean(impl_spect_40_t_1')' mean(impl_spect_40_t_1h')'];
     median_1 = [median(impl_spect_40_t_0')' median(impl_spect_40_t_1')' median(impl_spect_40_t_1h')'];
     
  
  %/**************** Summing up the CICs ******************/     
     cic_mat = [CIC1_1; CIC1h_1; CIC1_2; CIC1h_2];
 
     
  %/**************** Saving the results ******************/  
  
     if infospec == 1; 
     
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\npCVM_sirf_whole_y_t.mat'];
       save(savefile,'npCVM_sirf_whole_t','-ascii'); 
    
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\npCVM_sirf_8to2_y_t.mat'];
       save(savefile,'npCVM_sirf_8to2_t','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\meanCVM_sirf_y_t.mat'];
       save(savefile,'mean_1','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\cicCVM_y_t.mat'];
       save(savefile,'cic_mat','-ascii'); 
     
    
    
    elseif infospec == 2;
        
    
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\npCVM_sirf_whole_c_t.mat'];
       save(savefile,'npCVM_sirf_whole_t','-ascii'); 
    
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\npCVM_sirf_8to2_c_t.mat'];
       save(savefile,'npCVM_sirf_8to2_t','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\meanCVM_sirf_c_t.mat'];
       save(savefile,'mean_1','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\cicCVM_c_t.mat'];
       save(savefile,'cic_mat','-ascii'); 
    

    end
     
     
     
     
     
   
%% /* Model spec 3*/
mspec = 3;


 %/**************** Loading SDMs of IRFs of DlnY or DlnC ******************/
  
  % Transitory Shocks 40 lags
   % Empirical
    loadsdm = [mainpath '\spec0\info' num2str(infospec) '\VAR' num2str(varlag) '\impl_spect_40_t.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_t_0 = impl_spect_40_t;
    impl_spect_40_t_0 = sortrows(impl_spect_40_t_0',1);
    impl_spect_40_t_0 = impl_spect_40_t_0(10:4990,:)';
   
  
   % Theoretical Non-Habit
  
    loadsdm = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\impl_spect_40_t.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_t_1 = impl_spect_40_t;
    impl_spect_40_t_1 = sortrows(impl_spect_40_t_1',1)';
    %impl_spect_40_t_1 = impl_spect_40_t_1(10:4990,:)';
   
 
   % Theoretical Habit
  
    loadsdm = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\habit\impl_spect_40_t.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_t_1h = impl_spect_40_t;
   impl_spect_40_t_1h = sortrows(impl_spect_40_t_1h',1)';
    %impl_spect_40_t_1h = impl_spect_40_t_1h(10:4990,:)';
   
  
    % Sample
    
    loadsdm = [mainpath '\spec0\info' num2str(infospec) '\VAR' num2str(varlag) '\sample_impl_spect_40_t.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_t_s = sample_impl_spect_40_t;
    
  
  %/**************** Calculating CVM statistics for whole frequency range ******************/
    
     [KS0,CVM0]=kscvm(impl_spect_40_t_0,impl_spect_40_t_s,1,98);
     [KS1,CVM1]=kscvm(impl_spect_40_t_1,impl_spect_40_t_s,1,98);
     [KS1h,CVM1h]=kscvm(impl_spect_40_t_1h,impl_spect_40_t_s,1,98);
   
  
    %/* Calculating CIC */
     CIC1_1=cic(CVM0, CVM1, 95);
     CIC1h_1=cic(CVM0, CVM1h, 95);
  
    %/* Printing CICs */ 
     disp(sprintf('SP whole: CIC of non-habit:   %10.3f', CIC1_1 ));
     disp(sprintf('SP whole: CIC of habit:   %10.3f', CIC1h_1 ));
  
  
   %/* Nonparametric kernel density estimation of CVM */
     np=1000;
     ndrop0 = 10;
     ndrop1 = 10;
     ndrop2 = 10;
  
     CVMMAT0 = sort(CVM0,1);
     CVMMAT1 = sort(CVM1,1);
     CVMMAT1h = sort(CVM1h,1);
    
     [ndraw,junk] = size(CVM0);
   
     [YY0_1,XX0_1]=ndens(CVMMAT0(1:ndraw-ndrop0),100,ndraw-ndrop0);
     [YY1_1,XX1_1]=ndens(CVMMAT1(1:5000-ndrop1,1),100,5000-ndrop1);
     [YY1h_1,XX1h_1]=ndens(CVMMAT1h(1:5000-ndrop2,1),100,5000-ndrop2);
   
     npCVM_sirf_whole_t = [YY0_1 XX0_1 YY1_1 XX1_1 YY1h_1 XX1h_1];

    
  %/**************** Calculating CVM statistics for business cycle frequencies between 8 years and 2 years per cycle ******************/
     [KS0,CVM0]=kscvm(impl_spect_40_t_0,impl_spect_40_t_s,6,24);
     [KS1,CVM1]=kscvm(impl_spect_40_t_1,impl_spect_40_t_s,6,24);
     [KS1h,CVM1h]=kscvm(impl_spect_40_t_1h,impl_spect_40_t_s,6,24);
   
     
    %/* Calculating CIC */
     CIC1_2=cic(CVM0, CVM1, 95);
     CIC1h_2=cic(CVM0, CVM1h, 95);
  
  
    %/* Printing CICs */ 
     disp(sprintf('SP BC: CIC of non-habit:   %10.3f', CIC1_2 ));
     disp(sprintf('SP BC: CIC of habit:   %10.3f', CIC1h_2 ));
  
  
   
   %/* Nonparametric kernel density estimation of CVM */
     np=1000;
     ndrop0 = 10;
     ndrop1 = 10;
     ndrop2 = 10;
  
     CVMMAT0 = sort(CVM0,1);
     CVMMAT1 = sort(CVM1,1);
     CVMMAT1h = sort(CVM1h,1);
 
    [ndraw,junk] = size(CVM0);
   
     [YY0_2,XX0_2]=ndens(CVMMAT0(1:ndraw-ndrop0),100,ndraw-ndrop0);
     [YY1_2,XX1_2]=ndens(CVMMAT1(1:5000-ndrop1,1),100,5000-ndrop1);
     [YY1h_2,XX1h_2]=ndens(CVMMAT1h(1:5000-ndrop2,1),100,5000-ndrop2);
   
     npCVM_sirf_8to2_t = [YY0_2 XX0_2 YY1_2 XX1_2 YY1h_2 XX1h_2];
    
     
     
  %/**************** Mean and Median SDMs of IRFs of DlnY ******************/
     mean_1 = [mean(impl_spect_40_t_0')' mean(impl_spect_40_t_1')' mean(impl_spect_40_t_1h')'];
     median_1 = [median(impl_spect_40_t_0')' median(impl_spect_40_t_1')' median(impl_spect_40_t_1h')'];
     
  
  %/**************** Summing up the CICs ******************/  
   
     cic_mat = [CIC1_1; CIC1h_1; CIC1_2; CIC1h_2];
     
   %/**************** Saving the results ******************/     
   
     if infospec == 1; 
     
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\npCVM_sirf_whole_y_t.mat'];
       save(savefile,'npCVM_sirf_whole_t','-ascii'); 
    
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\npCVM_sirf_8to2_y_t.mat'];
       save(savefile,'npCVM_sirf_8to2_t','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\meanCVM_sirf_y_t.mat'];
       save(savefile,'mean_1','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\cicCVM_y_t.mat'];
       save(savefile,'cic_mat','-ascii'); 
     
     
    
    elseif infospec == 2;
        

       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\npCVM_sirf_whole_c_t.mat'];
       save(savefile,'npCVM_sirf_whole_t','-ascii'); 
    
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\npCVM_sirf_8to2_c_t.mat'];
       save(savefile,'npCVM_sirf_8to2_t','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\mean_sirf_c_t.mat'];
       save(savefile,'mean_1','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\cic_c_t.mat'];
       save(savefile,'cic_mat','-ascii'); 
    

    end
     
     
     