%/*************************************************************************
%**  
%**  This program derives the KS statistics of the SDs 
%**    NKMBCs with Taylor rule (spec = 4,5,6)
%**    Permanent shocks
%**  
%**************************************************************************/

%/* filename:  kn_ks_sd_tr_p.m
%** created:  07/05/07
%** 
%*/

clear;
clc

%/* Set the path */
pathspec;


support = [0:0.1:10];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Information sets
% infospec 
%           = 1: [DlnY DlnP]
%           = 2: [DlnC DlnP]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%          
infospec = 2;   


%/* VAR lag length */
varlag = 2;


%% /* Model spec 4*/
mspec = 4;


  %/**************** Loading SDMs of IRFs of DlnY or DlnC ******************/
 
  % Permanent Shocks 40 lags
   % Empirical
    loadsdm = [mainpath '\spec0\info' num2str(infospec) '\VAR' num2str(varlag) '\impl_spect_40_p.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_p_0 = impl_spect_40_p;
    impl_spect_40_p_0 = sortrows(impl_spect_40_p_0',1);
    impl_spect_40_p_0 = impl_spect_40_p_0(10:4990,:)';
   
  
   % Theoretical Non-Habit
  
    loadsdm = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\impl_spect_40_p.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_p_1 = impl_spect_40_p;
    impl_spect_40_p_1 = sortrows(impl_spect_40_p_1',1)';
    %impl_spect_40_p_1 = impl_spect_40_p_1(10:4990,:)';
   
 
   % Theoretical Habit
  
    loadsdm = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\habit\impl_spect_40_p.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_p_1h = impl_spect_40_p;
    impl_spect_40_p_1h = sortrows(impl_spect_40_p_1h',1)';
    %impl_spect_40_p_1h = impl_spect_40_p_1h(10:4990,:)';
   
  
    % Sample
    
    loadsdm = [mainpath '\spec0\info' num2str(infospec) '\VAR' num2str(varlag) '\sample_impl_spect_40_p.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_p_s = sample_impl_spect_40_p;
    
  
  %/**************** Calculating KS statistics for whole frequency range ******************/
    
     [KS0,CVM0]=kscvm(impl_spect_40_p_0,impl_spect_40_p_s,1,98);
     [KS1,CVM1]=kscvm(impl_spect_40_p_1,impl_spect_40_p_s,1,98);
     [KS1h,CVM1h]=kscvm(impl_spect_40_p_1h,impl_spect_40_p_s,1,98);
  
  
    %/* Calculating CIC */
     CIC1_1=cic(KS0, KS1, 95);
     CIC1h_1=cic(KS0, KS1h, 95);
  
    %/* Printing CICs */ 
     disp(sprintf('baseline whole: CIC of non-habit:   %10.3f', CIC1_1 ));
     disp(sprintf('baseline whole: CIC of habit:   %10.3f', CIC1h_1 ));
  
   %/* Nonparametric kernel density estimation of KS */
   
     np=1000;
     ndrop0 = 10;
     ndrop1 = 10;
     ndrop2 = 10;
  
     KSMAT0 = sort(KS0,1);
     KSMAT1 = sort(KS1,1);
     KSMAT1h = sort(KS1h,1);
    
     [ndraw,junk] = size(KS0);
   
     [YY0_1,XX0_1]=ndens(KSMAT0(1:ndraw-ndrop0),100,ndraw-ndrop0);
     [YY1_1,XX1_1]=ndens(KSMAT1(1:5000-ndrop1,1),100,5000-ndrop1);
     [YY1h_1,XX1h_1]=ndens(KSMAT1h(1:5000-ndrop2,1),100,5000-ndrop2);
   
     npks_sirf_whole_p = [YY0_1 XX0_1 YY1_1 XX1_1 YY1h_1 XX1h_1];

     
     
  %/**************** Calculating KS statistics for business cycle frequencies between 8 years and 2 years per cycle ******************/
    
     [KS0,CVM0]=kscvm(impl_spect_40_p_0,impl_spect_40_p_s,6,24);
     [KS1,CVM1]=kscvm(impl_spect_40_p_1,impl_spect_40_p_s,6,24);
     [KS1h,CVM1h]=kscvm(impl_spect_40_p_1h,impl_spect_40_p_s,6,24);
   
     
    %/* Calculating CIC */
     CIC1_2=cic(KS0, KS1, 95);
     CIC1h_2=cic(KS0, KS1h, 95);
  
  
    %/* Printing CICs */ 
     disp(sprintf('baseline BC: CIC of non-habit:   %10.3f', CIC1_2 ));
     disp(sprintf('baseline BC: CIC of habit:   %10.3f', CIC1h_2 ));
  
  
   
   %/* Nonparametric kernel density estimation of KS */
     np=1000;
     ndrop0 = 10;
     ndrop1 = 10;
     ndrop2 = 10;
  
     KSMAT0 = sort(KS0,1);
     KSMAT1 = sort(KS1,1);
     KSMAT1h = sort(KS1h,1);
    
  
     [ndraw,junk] = size(KS0);
     
     [YY0_2,XX0_2]=ndens(KSMAT0(1:ndraw-ndrop0),100,ndraw-ndrop0);
     [YY1_2,XX1_2]=ndens(KSMAT1(1:5000-ndrop1,1),100,5000-ndrop1);
     [YY1h_2,XX1h_2]=ndens(KSMAT1h(1:5000-ndrop2,1),100,5000-ndrop2);
   
     npks_sirf_8to2_p = [YY0_2 XX0_2 YY1_2 XX1_2 YY1h_2 XX1h_2];
    
     
     
  %/**************** Mean and Median SDMs of IRFs of DlnY ******************/
     mean_1 = [mean(impl_spect_40_p_0')' mean(impl_spect_40_p_1')' mean(impl_spect_40_p_1h')'];
     median_1 = [median(impl_spect_40_p_0')' median(impl_spect_40_p_1')' median(impl_spect_40_p_1h')'];
     
    
  
  %/**************** Summing up the CICs ******************/   
     cic_mat = [CIC1_1; CIC1h_1; CIC1_2; CIC1h_2];
     
   
  
  %/**************** Saving the results ******************/   
     if infospec == 1; 
     
      
       savefile = [mainpath '\spec' num2str(mspec) '\info1\VAR' num2str(varlag) '\npks_sirf_whole_y_p.mat'];
       save(savefile,'npks_sirf_whole_p','-ascii'); 
    
       savefile = [mainpath '\spec' num2str(mspec) '\info1\VAR' num2str(varlag) '\npks_sirf_8to2_y_p.mat'];
       save(savefile,'npks_sirf_8to2_p','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info1\VAR' num2str(varlag) '\mean_sirf_y_p.mat'];
       save(savefile,'mean_1','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info1\VAR' num2str(varlag) '\cic_y_p.mat'];
       save(savefile,'cic_mat','-ascii'); 
     
  
    
    elseif infospec == 2;
        
    
       savefile = [mainpath '\spec' num2str(mspec) '\info2\VAR' num2str(varlag) '\npks_sirf_whole_c_p.mat'];
       save(savefile,'npks_sirf_whole_p','-ascii'); 
    
       savefile = [mainpath '\spec' num2str(mspec) '\info2\VAR' num2str(varlag) '\npks_sirf_8to2_c_p.mat'];
       save(savefile,'npks_sirf_8to2_p','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info2\VAR' num2str(varlag) '\mean_sirf_c_p.mat'];
       save(savefile,'mean_1','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info2\VAR' num2str(varlag) '\cic_c_p.mat'];
       save(savefile,'cic_mat','-ascii'); 
    
    
  
    end
     
     
     
     
     
%% /* Model spec 5*/
mspec = 5;

  %/**************** Loading SDMs of IRFs of DlnY or DlnC ******************/
 
  % Permanent Shocks 40 lags
   % Empirical
    loadsdm = [mainpath '\spec0\info' num2str(infospec) '\VAR' num2str(varlag) '\impl_spect_40_p.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_p_0 = impl_spect_40_p;
    impl_spect_40_p_0 = sortrows(impl_spect_40_p_0',1);
    impl_spect_40_p_0 = impl_spect_40_p_0(10:4990,:)';
   
  
   % Theoretical Non-Habit
  
    loadsdm = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\impl_spect_40_p.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_p_1 = impl_spect_40_p;
    impl_spect_40_p_1 = sortrows(impl_spect_40_p_1',1)';
    %impl_spect_40_p_1 = impl_spect_40_p_1(10:4990,:)';
   
 
   % Theoretical Habit
  
    loadsdm = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\habit\impl_spect_40_p.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_p_1h = impl_spect_40_p;
   impl_spect_40_p_1h = sortrows(impl_spect_40_p_1h',1)';
    %impl_spect_40_p_1h = impl_spect_40_p_1h(10:4990,:)';
   
  
    % Sample
    
    loadsdm = [mainpath '\spec0\info' num2str(infospec) '\VAR' num2str(varlag) '\sample_impl_spect_40_p.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_p_s = sample_impl_spect_40_p;
    
  
  %/**************** Calculating KS statistics for whole frequency range ******************/
    
     [KS0,CVM0]=kscvm(impl_spect_40_p_0,impl_spect_40_p_s,1,98);
     [KS1,CVM1]=kscvm(impl_spect_40_p_1,impl_spect_40_p_s,1,98);
     [KS1h,CVM1h]=kscvm(impl_spect_40_p_1h,impl_spect_40_p_s,1,98);
   
  
    %/* Calculating CIC */
     CIC1_1=cic(KS0, KS1, 95);
     CIC1h_1=cic(KS0, KS1h, 95);
  
  
    %/* Printing CICs */ 
     disp(sprintf('SW whole: CIC of non-habit:   %10.3f', CIC1_1 ));
     disp(sprintf('SW whole: CIC of habit:   %10.3f', CIC1h_1 ));
  
 
   %/* Nonparametric kernel density estimation of KS */
     np=1000;
     ndrop0 = 10;
     ndrop1 = 10;
     ndrop2 = 10;
  
     KSMAT0 = sort(KS0,1);
     KSMAT1 = sort(KS1,1);
     KSMAT1h = sort(KS1h,1);
 
  
     [ndraw,junk] = size(KS0);
   
   
     [YY0_1,XX0_1]=ndens(KSMAT0(1:ndraw-ndrop0),100,ndraw-ndrop0);
     [YY1_1,XX1_1]=ndens(KSMAT1(1:5000-ndrop1,1),100,5000-ndrop1);
     [YY1h_1,XX1h_1]=ndens(KSMAT1h(1:5000-ndrop2,1),100,5000-ndrop2);
   
     
     npks_sirf_whole_p = [YY0_1 XX0_1 YY1_1 XX1_1 YY1h_1 XX1h_1];

     
     
  %/**************** Calculating KS statistics for business cycle frequencies between 8 years and 2 years per cycle ******************/
     [KS0,CVM0]=kscvm(impl_spect_40_p_0,impl_spect_40_p_s,6,24);
     [KS1,CVM1]=kscvm(impl_spect_40_p_1,impl_spect_40_p_s,6,24);
     [KS1h,CVM1h]=kscvm(impl_spect_40_p_1h,impl_spect_40_p_s,6,24);
   
    
    %/* Calculating CIC */
     CIC1_2=cic(KS0, KS1, 95);
     CIC1h_2=cic(KS0, KS1h, 95);
  
  
    %/* Printing CICs */ 
     disp(sprintf('SW BC: CIC of non-habit:   %10.3f', CIC1_2 ));
     disp(sprintf('SW BC: CIC of habit:   %10.3f', CIC1h_2 ));
  
  
   %/* Nonparametric kernel density estimation of KS */
     np=1000;
     ndrop0 = 10;
     ndrop1 = 10;
     ndrop2 = 10;
  
     KSMAT0 = sort(KS0,1);
     KSMAT1 = sort(KS1,1);
     KSMAT1h = sort(KS1h,1);
   
  
     [ndraw,junk] = size(KS0);
   
   
     [YY0_2,XX0_2]=ndens(KSMAT0(1:ndraw-ndrop0),100,ndraw-ndrop0);
     [YY1_2,XX1_2]=ndens(KSMAT1(1:5000-ndrop1,1),100,5000-ndrop1);
     [YY1h_2,XX1h_2]=ndens(KSMAT1h(1:5000-ndrop2,1),100,5000-ndrop2);
   
      npks_sirf_8to2_p = [YY0_2 XX0_2 YY1_2 XX1_2 YY1h_2 XX1h_2];
    
     
     
     
  %/**************** Mean and Median SDMs of IRFs of DlnY ******************/
     mean_1 = [mean(impl_spect_40_p_0')' mean(impl_spect_40_p_1')' mean(impl_spect_40_p_1h')'];
     median_1 = [median(impl_spect_40_p_0')' median(impl_spect_40_p_1')' median(impl_spect_40_p_1h')'];
     
  
  %/**************** Summing up the CICs ******************/     
     cic_mat = [CIC1_1; CIC1h_1; CIC1_2; CIC1h_2];
 
     
  %/**************** Saving the results ******************/  
  
     if infospec == 1; 
     
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\npks_sirf_whole_y_p.mat'];
       save(savefile,'npks_sirf_whole_p','-ascii'); 
    
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\npks_sirf_8to2_y_p.mat'];
       save(savefile,'npks_sirf_8to2_p','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\mean_sirf_y_p.mat'];
       save(savefile,'mean_1','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\cic_y_p.mat'];
       save(savefile,'cic_mat','-ascii'); 
    
    
    elseif infospec == 2;
        
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\npks_sirf_whole_c_p.mat'];
       save(savefile,'npks_sirf_whole_p','-ascii'); 
    
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\npks_sirf_8to2_c_p.mat'];
       save(savefile,'npks_sirf_8to2_p','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\mean_sirf_c_p.mat'];
       save(savefile,'mean_1','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\cic_c_p.mat'];
       save(savefile,'cic_mat','-ascii'); 
    

    end
     
     
     
     
     
   
%% /* Model spec 6*/
mspec = 6;


 %/**************** Loading SDMs of IRFs of DlnY or DlnC ******************/
  
  % Permanent Shocks 40 lags
   % Empirical
    loadsdm = [mainpath '\spec0\info' num2str(infospec) '\VAR' num2str(varlag) '\impl_spect_40_p.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_p_0 = impl_spect_40_p;
    impl_spect_40_p_0 = sortrows(impl_spect_40_p_0',1);
    impl_spect_40_p_0 = impl_spect_40_p_0(10:4990,:)';
   
  
   % Theoretical Non-Habit
  
    loadsdm = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\impl_spect_40_p.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_p_1 = impl_spect_40_p;
    impl_spect_40_p_1 = sortrows(impl_spect_40_p_1',1)';
    %impl_spect_40_p_1 = impl_spect_40_p_1(10:4990,:)';
   
 
   % Theoretical Habit
  
    loadsdm = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\habit\impl_spect_40_p.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_p_1h = impl_spect_40_p;
   impl_spect_40_p_1h = sortrows(impl_spect_40_p_1h',1)';
    %impl_spect_40_p_1h = impl_spect_40_p_1h(10:4990,:)';
   
  
    % Sample
    
    loadsdm = [mainpath '\spec0\info' num2str(infospec) '\VAR' num2str(varlag) '\sample_impl_spect_40_p.mat'];
    load(loadsdm,'-ascii')
    impl_spect_40_p_s = sample_impl_spect_40_p;
    
  
  %/**************** Calculating KS statistics for whole frequency range ******************/
    
     [KS0,CVM0]=kscvm(impl_spect_40_p_0,impl_spect_40_p_s,1,98);
     [KS1,CVM1]=kscvm(impl_spect_40_p_1,impl_spect_40_p_s,1,98);
     [KS1h,CVM1h]=kscvm(impl_spect_40_p_1h,impl_spect_40_p_s,1,98);
   
  
    %/* Calculating CIC */
     CIC1_1=cic(KS0, KS1, 95);
     CIC1h_1=cic(KS0, KS1h, 95);
  
    %/* Printing CICs */ 
     disp(sprintf('SP whole: CIC of non-habit:   %10.3f', CIC1_1 ));
     disp(sprintf('SP whole: CIC of habit:   %10.3f', CIC1h_1 ));
  
  
   %/* Nonparametric kernel density estimation of KS */
     np=1000;
     ndrop0 = 10;
     ndrop1 = 10;
     ndrop2 = 10;
  
     KSMAT0 = sort(KS0,1);
     KSMAT1 = sort(KS1,1);
     KSMAT1h = sort(KS1h,1);
    
     [ndraw,junk] = size(KS0);
   
     [YY0_1,XX0_1]=ndens(KSMAT0(1:ndraw-ndrop0),100,ndraw-ndrop0);
     [YY1_1,XX1_1]=ndens(KSMAT1(1:5000-ndrop1,1),100,5000-ndrop1);
     [YY1h_1,XX1h_1]=ndens(KSMAT1h(1:5000-ndrop2,1),100,5000-ndrop2);
   
     npks_sirf_whole_p = [YY0_1 XX0_1 YY1_1 XX1_1 YY1h_1 XX1h_1];

    
  %/**************** Calculating KS statistics for business cycle frequencies between 8 years and 2 years per cycle ******************/
     [KS0,CVM0]=kscvm(impl_spect_40_p_0,impl_spect_40_p_s,6,24);
     [KS1,CVM1]=kscvm(impl_spect_40_p_1,impl_spect_40_p_s,6,24);
     [KS1h,CVM1h]=kscvm(impl_spect_40_p_1h,impl_spect_40_p_s,6,24);
   
     
    %/* Calculating CIC */
     CIC1_2=cic(KS0, KS1, 95);
     CIC1h_2=cic(KS0, KS1h, 95);
  
  
    %/* Printing CICs */ 
     disp(sprintf('SP BC: CIC of non-habit:   %10.3f', CIC1_2 ));
     disp(sprintf('SP BC: CIC of habit:   %10.3f', CIC1h_2 ));
  
  
   
   %/* Nonparametric kernel density estimation of KS */
     np=1000;
     ndrop0 = 10;
     ndrop1 = 10;
     ndrop2 = 10;
  
     KSMAT0 = sort(KS0,1);
     KSMAT1 = sort(KS1,1);
     KSMAT1h = sort(KS1h,1);
 
    [ndraw,junk] = size(KS0);
   
     [YY0_2,XX0_2]=ndens(KSMAT0(1:ndraw-ndrop0),100,ndraw-ndrop0);
     [YY1_2,XX1_2]=ndens(KSMAT1(1:5000-ndrop1,1),100,5000-ndrop1);
     [YY1h_2,XX1h_2]=ndens(KSMAT1h(1:5000-ndrop2,1),100,5000-ndrop2);
   
     npks_sirf_8to2_p = [YY0_2 XX0_2 YY1_2 XX1_2 YY1h_2 XX1h_2];
    
     
     
  %/**************** Mean and Median SDMs of IRFs of DlnY ******************/
     mean_1 = [mean(impl_spect_40_p_0')' mean(impl_spect_40_p_1')' mean(impl_spect_40_p_1h')'];
     median_1 = [median(impl_spect_40_p_0')' median(impl_spect_40_p_1')' median(impl_spect_40_p_1h')'];
     
  
  %/**************** Summing up the CICs ******************/  
   
     cic_mat = [CIC1_1; CIC1h_1; CIC1_2; CIC1h_2];
     
   %/**************** Saving the results ******************/     
   
     if infospec == 1; 
     
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\npks_sirf_whole_y_p.mat'];
       save(savefile,'npks_sirf_whole_p','-ascii'); 
    
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\npks_sirf_8to2_y_p.mat'];
       save(savefile,'npks_sirf_8to2_p','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\mean_sirf_y_p.mat'];
       save(savefile,'mean_1','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\cic_y_p.mat'];
       save(savefile,'cic_mat','-ascii'); 
     
    
    elseif infospec == 2;
        

       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\npks_sirf_whole_c_p.mat'];
       save(savefile,'npks_sirf_whole_p','-ascii'); 
    
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\npks_sirf_8to2_c_p.mat'];
       save(savefile,'npks_sirf_8to2_p','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\mean_sirf_c_p.mat'];
       save(savefile,'mean_1','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infospec) '\VAR' num2str(varlag) '\cic_c_p.mat'];
       save(savefile,'cic_mat','-ascii'); 
    

    end
     
     
     