%/*************************************************************************
%**  
%**  This program simulates NKMBC models, estimate the IRFs, and calculate
%**    the SDs
%**  
%**************************************************************************/

%/* filename:  kn_modelsim.m
%   Converted from Gauss file knmodel_sim_1005.g:  06/24/06
%   modified: 06/30/07
%             07/24/09
%*
%*
%*/
clear; clc;


%/* Set the path */
pathspec;


%/* Model's spec */
%   mspec = 1: NKMBC with AR money growth  
%         = 2; NKMBC with AR money growth and flexible price (S-Wage)
%         = 3; NKMBC with AR money growth and flexible wage (S-Price)
%         = 4; NKMBC with Taylor rule
%         = 5; NKMBC with Taylor rule and flexible price (S-Wage)
%         = 6: NKMBC with Taylor rule and flexible wage (S-Price)
%        
%

mspec = 6;

%/* Habit or not */
%   mhabit = 0: non-habit 
%          = 1; habit

mhabit = 1;

% VAR lags
%  varlag = 2 or 4
%
varlag = 2;


  if (mspec == 1) || (mspec == 2) || (mspec == 3) ;
     
      infoid = [1;2];
  elseif (mspec == 4) || (mspec == 5) || (mspec == 6) ;
     
      infoid = [1;2];
  end;


%/* Load the prior */

  
 loadprior = [mainpath '\spec' num2str(mspec) '\priorsim.mat'];
 load(loadprior,'-ascii')
 priormat = priorsim'; 
 
 
 
%/* Number of draws and horizons for IRFs and FEVDs */
ndraw=5500;
horizon =41;



%/* Storages */
 IMPL11_1=zeros(horizon,ndraw);
 IMPL12_1=zeros(horizon,ndraw);
 IMPL11g_1=zeros(horizon,ndraw);
 IMPL12g_1=zeros(horizon,ndraw);
 IMPL21_1=zeros(horizon,ndraw);
 IMPL22_1=zeros(horizon,ndraw);
 
 IMPL11_2=zeros(horizon,ndraw);
 IMPL12_2=zeros(horizon,ndraw);
 IMPL11g_2=zeros(horizon,ndraw);
 IMPL12g_2=zeros(horizon,ndraw);
 IMPL21_2=zeros(horizon,ndraw);
 IMPL22_2=zeros(horizon,ndraw);

 sdmdy_1=zeros(314,ndraw);
 sdmdc_1=zeros(314,ndraw);
 sdmdy_8=zeros(314,ndraw);
 sdmdc_8=zeros(314,ndraw);

 IMPL_SPECT_40_p_1 = zeros(314,ndraw);
 IMPL_SPECT_12_p_1 = zeros(314,ndraw);
 IMPL_SPECT_20_p_1 = zeros(314,ndraw);
 IMPL_SPECT_40_p_2 = zeros(314,ndraw);
 IMPL_SPECT_12_p_2 = zeros(314,ndraw);
 IMPL_SPECT_20_p_2 = zeros(314,ndraw);
 IMPL_SPECT_40_t_1 = zeros(314,ndraw);
 IMPL_SPECT_12_t_1 = zeros(314,ndraw);
 IMPL_SPECT_20_t_1 = zeros(314,ndraw);
 IMPL_SPECT_40_t_2 = zeros(314,ndraw);
 IMPL_SPECT_12_t_2 = zeros(314,ndraw);
 IMPL_SPECT_20_t_2 = zeros(314,ndraw);
 
 IMPL_SPECT_INF_40_p_1 = zeros(314,ndraw);
 IMPL_SPECT_INF_40_p_2 = zeros(314,ndraw);
 IMPL_SPECT_INF_40_t_1 = zeros(314,ndraw);
 IMPL_SPECT_INF_40_t_2 = zeros(314,ndraw);

valid = 0;
reject = 0;
reject_multi = 0;

abcd_count_y = 0;
abcd_count_c = 0;

%
% Set seed of state of normal random number generator
%
seedn = 3002001;
randn('state',seedn);
rand('state',seedn);

nst_mat = 0;
nbar_mat = 0;

i = 1;
 while  i <= ndraw;
      clc
      disp(sprintf('No of draws:   %10.3f', i));
      %disp(sprintf('No of rejections:   %10.3f', reject));
      %disp(sprintf('No of multiple eq:   %10.3f', reject_multi));
 
       [sst,valid] = knsst(priormat(:,i), mspec);
      % nst_mat = [nst_mat; sst(4)];
      % nbar_mat = [nbar_mat; sst(11)];
      
    % Drawing the artificial time series
      [Simdata,sig,valid,eig_FVRRSW_y, eig_FVRRSW_c] = kn_artdraw(priormat(:,i), mspec, mhabit);
      
     
      
      [nobsim,junk] = size(Simdata);

          if (valid == 2);
             reject_multi = reject_multi + 1;
          end;

    % Rejecting the draw under no existence or non-uniqueness of the equilibrium

     if (valid == 1) | (valid == 2);
       %  priormat(14:15,i)  
        disp(sprintf('valid:   %10.3f', valid));
        
       reject = reject + 1;
   
     else;
   
 
      DY=Simdata(2:nobsim,1)-Simdata(1:nobsim-1,1); 
      DC=Simdata(2:nobsim,2)-Simdata(1:nobsim-1,2);
      DI=Simdata(2:nobsim,3)-Simdata(1:nobsim-1,3);
      N =Simdata(2:nobsim,4); 
      DY = 400.*DY;
      DC = 400.*DC;
      N  = 400.*N;
      
      
     DP=Simdata(2:nobsim,7)+Simdata(2:nobsim,8)-Simdata(2:nobsim,9)+Simdata(1:nobsim-1,9);
     DP = 400.*DP;
   
     
     % ABCD count
     
      if max(abs(eig_FVRRSW_y))>=1
          abcd_count_y =  abcd_count_y + 1;
      else
          abcd_count_y = abcd_count_y + 0;
      end
      
      
      if max(abs(eig_FVRRSW_c))>=1
          abcd_count_c =  abcd_count_c + 1;
      else
          abcd_count_c = abcd_count_c + 0;
      end
 
    %/* Impulse response function */
 

    for d = 1:2;   

       if (infoid(d) ==1);
          Info = [DY  DP]; lags =varlag;
        
       elseif (infoid(d) == 2);
          Info = [DC  DP]; lags =varlag; 
         
        
       end;
  
       
         
           xtilde = VARData(Info,lags);
           [nobs,cols] = size(xtilde); 
           DepData = xtilde(:,1:2);
           IndData = [xtilde(:,3:cols) ones(nobs,1)];
           Bdraw = inv(IndData'*IndData)*IndData'*DepData;
           Resid = DepData - IndData*Bdraw;
           VCOV  = Resid'*Resid/nobs;
      
      
      [row_bdraw,junk] = size(Bdraw);
  
      Bdraw = Bdraw(1:row_bdraw-1,:);
      
      CMat = [ Bdraw';
               eye(2*(lags-1))  zeros(2*(lags-1),2)];
      
      eigval = abs(real(eig(CMat)));
 
 
       if (max(eigval) >= 1) ;
        valid = 1;
        %"valid2   " valid;
         reject = reject + 1;
       
       end;

     % BQ long-run decomposition code by Jim: revised 08/02/06 
       [c00, smimp1, smimp2, smimpl1, smimpl2] ...
                           = bqdecomp(Bdraw, VCOV, eye(2) ,lags, nobs) ;
    
                
                        
       if imag(c00) ~ zeros(2,2);
         valid = 3
         %"valid3   " valid;
         reject = reject + 1;
       end;                  
                       
           
          
     
       if d == 1;
         
         IMPL11_1(:,i)=real(smimpl1(1:horizon,1))';
         IMPL12_1(:,i)=real(smimpl1(1:horizon,2))';
         IMPL11g_1(:,i)=real(smimp1(1:horizon,1))';
         IMPL12g_1(:,i)=real(smimp1(1:horizon,2))';    
         IMPL21_1(:,i)=real(smimp2(1:horizon,1))';
         IMPL22_1(:,i)=real(smimp2(1:horizon,2))';     
         
         IMPL_SPECT_40_p_1(1,i) = real(svmaspect(0,smimp1(:,1),40));
         IMPL_SPECT_12_p_1(1,i) = real(svmaspect(0,smimp1(:,1),12));
         IMPL_SPECT_20_p_1(1,i) = real(svmaspect(0,smimp1(:,1),20));
         IMPL_SPECT_40_t_1(1,i) = real(svmaspect(0,smimp1(:,2),40));
         IMPL_SPECT_12_t_1(1,i) = real(svmaspect(0,smimp1(:,2),12));
         IMPL_SPECT_20_t_1(1,i) = real(svmaspect(0,smimp1(:,2),20));
     
         IMPL_SPECT_INF_40_p_1(1,i) = real(svmaspect(0,smimp2(:,1),40));
         IMPL_SPECT_INF_40_t_1(1,i) = real(svmaspect(0,smimp2(:,2),40));
         
         for j = 2:314;
          omega = j/100;
           IMPL_SPECT_40_p_1(j,i) = real(svmaspect(omega,smimp1(:,1),40));
           IMPL_SPECT_12_p_1(j,i) = real(svmaspect(omega,smimp1(:,1),12));
           IMPL_SPECT_20_p_1(j,i) = real(svmaspect(omega,smimp1(:,1),20));
           IMPL_SPECT_40_t_1(j,i) = real(svmaspect(omega,smimp1(:,2),40));
           IMPL_SPECT_12_t_1(j,i) = real(svmaspect(omega,smimp1(:,2),12));
           IMPL_SPECT_20_t_1(j,i) = real(svmaspect(omega,smimp1(:,2),20));
            
           IMPL_SPECT_INF_40_p_1(j,i) = real(svmaspect(omega,smimp2(:,1),40));
           IMPL_SPECT_INF_40_t_1(j,i) = real(svmaspect(omega,smimp2(:,2),40));
           
         end; 
         
         
        
         
       else;
         
         IMPL11_2(:,i)=real(smimpl1(1:horizon,1))';
         IMPL12_2(:,i)=real(smimpl1(1:horizon,2))';
         IMPL11g_2(:,i)=real(smimp1(1:horizon,1))';
         IMPL12g_2(:,i)=real(smimp1(1:horizon,2))';    
         IMPL21_2(:,i)=real(smimp2(1:horizon,1))';
         IMPL22_2(:,i)=real(smimp2(1:horizon,2))';    
         
         IMPL_SPECT_40_p_2(1,i) = real(svmaspect(0,smimp1(:,1),40));
         IMPL_SPECT_12_p_2(1,i) = real(svmaspect(0,smimp1(:,1),12));
         IMPL_SPECT_20_p_2(1,i) = real(svmaspect(0,smimp1(:,1),20));
         IMPL_SPECT_40_t_2(1,i) = real(svmaspect(0,smimp1(:,2),40));
         IMPL_SPECT_12_t_2(1,i) = real(svmaspect(0,smimp1(:,2),12));
         IMPL_SPECT_20_t_2(1,i) = real(svmaspect(0,smimp1(:,2),20));
         
         IMPL_SPECT_INF_40_p_2(1,i) = real(svmaspect(0,smimp2(:,1),40));
         IMPL_SPECT_INF_40_t_2(1,i) = real(svmaspect(0,smimp2(:,2),40));
     
         for j = 2:314;
          omega = j/100;
           IMPL_SPECT_40_p_2(j,i) = real(svmaspect(omega,smimp1(:,1),40));
           IMPL_SPECT_12_p_2(j,i) = real(svmaspect(omega,smimp1(:,1),12));
           IMPL_SPECT_20_p_2(j,i) = real(svmaspect(omega,smimp1(:,1),20));
           IMPL_SPECT_40_t_2(j,i) = real(svmaspect(omega,smimp1(:,2),40));
           IMPL_SPECT_12_t_2(j,i) = real(svmaspect(omega,smimp1(:,2),12));
           IMPL_SPECT_20_t_2(j,i) = real(svmaspect(omega,smimp1(:,2),20));
             
           IMPL_SPECT_INF_40_p_2(j,i) = real(svmaspect(omega,smimp2(:,1),40));
           IMPL_SPECT_INF_40_t_2(j,i) = real(svmaspect(omega,smimp2(:,2),40));
         end; 
         
         
         
       end;

       
    end;
 
  
   end;
 
   
   if valid == 0; 
       reject = reject;
       i = i + 1;
     else
       i = i+1;
       
       
     end; 
   
   
end;


   %/* Save the results */
     
     if mhabit == 0;
       
      IMPL_SPECT_40_p_1 = IMPL_SPECT_40_p_1(:,1:5000);
      IMPL_SPECT_12_p_1 = IMPL_SPECT_12_p_1(:,1:5000);
      IMPL_SPECT_20_p_1 = IMPL_SPECT_20_p_1(:,1:5000);
      
      IMPL_SPECT_40_t_1 = IMPL_SPECT_40_t_1(:,1:5000);
      IMPL_SPECT_12_t_1 = IMPL_SPECT_12_t_1(:,1:5000);
      IMPL_SPECT_20_t_1 = IMPL_SPECT_20_t_1(:,1:5000);
      
      
      IMPL_SPECT_40_p_2 = IMPL_SPECT_40_p_2(:,1:5000);
      IMPL_SPECT_12_p_2 = IMPL_SPECT_12_p_2(:,1:5000);
      IMPL_SPECT_20_p_2 = IMPL_SPECT_20_p_2(:,1:5000);
      
      IMPL_SPECT_40_t_2 = IMPL_SPECT_40_t_2(:,1:5000);
      IMPL_SPECT_12_t_2 = IMPL_SPECT_12_t_2(:,1:5000);
      IMPL_SPECT_20_t_2 = IMPL_SPECT_20_t_2(:,1:5000);
       
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(1)) '\VAR' num2str(varlag) '\impl_spect_40_p.mat'];
       save(savefile,'IMPL_SPECT_40_p_1','-ascii'); 
       
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(1)) '\VAR' num2str(varlag) '\impl_spect_12_p.mat'];
       save(savefile,'IMPL_SPECT_12_p_1','-ascii'); 
       
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(1)) '\VAR' num2str(varlag) '\impl_spect_20_p.mat'];
       save(savefile,'IMPL_SPECT_20_p_1','-ascii'); 
       
       
        savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(1)) '\VAR' num2str(varlag) '\impl_spect_40_t.mat'];
       save(savefile,'IMPL_SPECT_40_t_1','-ascii'); 
       
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(1)) '\VAR' num2str(varlag) '\impl_spect_12_t.mat'];
       save(savefile,'IMPL_SPECT_12_t_1','-ascii'); 
       
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(1)) '\VAR' num2str(varlag) '\impl_spect_20_t.mat'];
       save(savefile,'IMPL_SPECT_20_t_1','-ascii'); 
       
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(2)) '\VAR' num2str(varlag) '\impl_spect_40_p.mat'];
       save(savefile,'IMPL_SPECT_40_p_2','-ascii'); 
       
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(2)) '\VAR' num2str(varlag) '\impl_spect_12_p.mat'];
       save(savefile,'IMPL_SPECT_12_p_2','-ascii'); 
       
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(2)) '\VAR' num2str(varlag) '\impl_spect_20_p.mat'];
       save(savefile,'IMPL_SPECT_20_p_2','-ascii'); 
       
       
        savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(2)) '\VAR' num2str(varlag) '\impl_spect_40_t.mat'];
       save(savefile,'IMPL_SPECT_40_t_2','-ascii'); 
         
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(2)) '\VAR' num2str(varlag) '\impl_spect_12_t.mat'];
       save(savefile,'IMPL_SPECT_12_t_2','-ascii'); 
       
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(2)) '\VAR' num2str(varlag) '\impl_spect_20_t.mat'];
       save(savefile,'IMPL_SPECT_20_t_2','-ascii'); 
       
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(1)) '\VAR' num2str(varlag) '\impl_spect_INF_40_p.mat'];
       save(savefile,'IMPL_SPECT_INF_40_p_1','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(2)) '\VAR' num2str(varlag) '\impl_spect_INF_40_p.mat'];
       save(savefile,'IMPL_SPECT_INF_40_p_2','-ascii'); 
       
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(1)) '\VAR' num2str(varlag) '\impl_spect_INF_40_t.mat'];
       save(savefile,'IMPL_SPECT_INF_40_t_1','-ascii'); 
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(2)) '\VAR' num2str(varlag) '\impl_spect_INF_40_t.mat'];
       save(savefile,'IMPL_SPECT_INF_40_t_2','-ascii'); 
       
       
      elseif mhabit == 1;
        
      IMPL_SPECT_40_p_1 = IMPL_SPECT_40_p_1(:,1:5000);
      IMPL_SPECT_12_p_1 = IMPL_SPECT_12_p_1(:,1:5000);
      IMPL_SPECT_20_p_1 = IMPL_SPECT_20_p_1(:,1:5000);
      
      IMPL_SPECT_40_t_1 = IMPL_SPECT_40_t_1(:,1:5000);
      IMPL_SPECT_12_t_1 = IMPL_SPECT_12_t_1(:,1:5000);
      IMPL_SPECT_20_t_1 = IMPL_SPECT_20_t_1(:,1:5000);
      
      
      IMPL_SPECT_40_p_2 = IMPL_SPECT_40_p_2(:,1:5000);
      IMPL_SPECT_12_p_2 = IMPL_SPECT_12_p_2(:,1:5000);
      IMPL_SPECT_20_p_2 = IMPL_SPECT_20_p_2(:,1:5000);
      
      IMPL_SPECT_40_t_2 = IMPL_SPECT_40_t_2(:,1:5000);
      IMPL_SPECT_12_t_2 = IMPL_SPECT_12_t_2(:,1:5000);
      IMPL_SPECT_20_t_2 = IMPL_SPECT_20_t_2(:,1:5000);
        
        
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(1)) '\VAR' num2str(varlag) '\habit\impl_spect_40_p.mat'];
       save(savefile,'IMPL_SPECT_40_p_1','-ascii'); 
       
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(1)) '\VAR' num2str(varlag) '\habit\impl_spect_12_p.mat'];
       save(savefile,'IMPL_SPECT_12_p_1','-ascii'); 
       
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(1)) '\VAR' num2str(varlag) '\habit\impl_spect_20_p.mat'];
       save(savefile,'IMPL_SPECT_20_p_1','-ascii'); 
       
       
        savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(1)) '\VAR' num2str(varlag) '\habit\impl_spect_40_t.mat'];
       save(savefile,'IMPL_SPECT_40_t_1','-ascii'); 
       
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(1)) '\VAR' num2str(varlag) '\habit\impl_spect_12_t.mat'];
       save(savefile,'IMPL_SPECT_12_t_1','-ascii'); 
       
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(1)) '\VAR' num2str(varlag) '\habit\impl_spect_20_t.mat'];
       save(savefile,'IMPL_SPECT_20_t_1','-ascii'); 
       
       
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(2)) '\VAR' num2str(varlag) '\habit\impl_spect_40_p.mat'];
       save(savefile,'IMPL_SPECT_40_p_2','-ascii'); 
       
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(2)) '\VAR' num2str(varlag) '\habit\impl_spect_12_p.mat'];
       save(savefile,'IMPL_SPECT_12_p_2','-ascii'); 
       
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(2)) '\VAR' num2str(varlag) '\habit\impl_spect_20_p.mat'];
       save(savefile,'IMPL_SPECT_20_p_2','-ascii'); 
       
       
        savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(2)) '\VAR' num2str(varlag) '\habit\impl_spect_40_t.mat'];
       save(savefile,'IMPL_SPECT_40_t_2','-ascii'); 
       
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(2)) '\VAR' num2str(varlag) '\habit\impl_spect_12_t.mat'];
       save(savefile,'IMPL_SPECT_12_t_2','-ascii'); 
       
      
       savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(2)) '\VAR' num2str(varlag) '\habit\impl_spect_20_t.mat'];
       save(savefile,'IMPL_SPECT_20_t_2','-ascii'); 
       
       
      % savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(1)) '\VAR' num2str(varlag) '\habit\impl_spect_INF_40_p.mat'];
      % save(savefile,'IMPL_SPECT_INF_40_p_1','-ascii'); 
       
      % savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(2)) '\VAR' num2str(varlag) '\habit\impl_spect_INF_40_p.mat'];
      % save(savefile,'IMPL_SPECT_INF_40_p_2','-ascii'); 
      
      % savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(1)) '\VAR' num2str(varlag) '\habit\impl_spect_INF_40_t.mat'];
      % save(savefile,'IMPL_SPECT_INF_40_t_1','-ascii'); 
       
      % savefile = [mainpath '\spec' num2str(mspec) '\info' num2str(infoid(2)) '\VAR' num2str(varlag) '\habit\impl_spect_INF_40_t.mat'];
      % save(savefile,'IMPL_SPECT_INF_40_t_2','-ascii'); 
       
     end;  
     
     
     
     
     
     
     
